Class: Aws::Lightsail::Types::AttachCertificateToDistributionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::AttachCertificateToDistributionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_name ⇒ String
The name of the certificate to attach to a distribution.
-
#distribution_name ⇒ String
The name of the distribution that the certificate will be attached to.
Instance Attribute Details
#certificate_name ⇒ String
The name of the certificate to attach to a distribution.
Only certificates with a status of ‘ISSUED` can be attached to a distribution.
Use the ‘GetCertificates` action to get a list of certificate names that you can specify.
<note markdown=“1”> This is the name of the certificate resource type and is used only to reference the certificate in other API actions. It can be different than the domain name of the certificate. For example, your certificate name might be ‘WordPress-Blog-Certificate` and the domain name of the certificate might be `example.com`.
</note>
673 674 675 676 677 678 |
# File 'lib/aws-sdk-lightsail/types.rb', line 673 class AttachCertificateToDistributionRequest < Struct.new( :distribution_name, :certificate_name) SENSITIVE = [] include Aws::Structure end |
#distribution_name ⇒ String
The name of the distribution that the certificate will be attached to.
Use the ‘GetDistributions` action to get a list of distribution names that you can specify.
673 674 675 676 677 678 |
# File 'lib/aws-sdk-lightsail/types.rb', line 673 class AttachCertificateToDistributionRequest < Struct.new( :distribution_name, :certificate_name) SENSITIVE = [] include Aws::Structure end |