Class: Aws::Lightsail::Types::CloseInstancePublicPortsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CloseInstancePublicPortsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An object that describes the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An object that describes the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
1992 1993 1994 1995 1996 |
# File 'lib/aws-sdk-lightsail/types.rb', line 1992 class CloseInstancePublicPortsResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |