Class: Aws::Lightsail::Types::ContactMethod

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Describes a contact method.

A contact method is a way to send you notifications. For more information, see [Notifications in Amazon Lightsail][1].

[1]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-notifications

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the contact method.

Returns:

  • (String)


2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#contact_endpointString

The destination of the contact method, such as an email address or a mobile phone number.

Returns:

  • (String)


2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the contact method was created.

Returns:

  • (Time)


2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::ResourceLocation

An object that describes the location of the contact method, such as the Amazon Web Services Region and Availability Zone.



2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the contact method.

Returns:

  • (String)


2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol of the contact method, such as email or SMS (text messaging).

Returns:

  • (String)


2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The Lightsail resource type of the contact method.

Returns:

  • (String)


2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the contact method.

A contact method has the following possible status:

  • PendingVerification - The contact method has not yet been verified, and the verification has not yet expired.

  • Valid - The contact method has been verified.

  • InValid - An attempt was made to verify the contact method, but the verification has expired.

Returns:

  • (String)


2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#support_codeString

The support code. Include this code in your email to support when you have questions about your Lightsail contact method. This code enables our support team to look up your Lightsail information more easily.

Returns:

  • (String)


2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tag keys and optional values for the resource. For more information about tags in Lightsail, see the [Amazon Lightsail Developer Guide][1].

[1]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-tags

Returns:



2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
# File 'lib/aws-sdk-lightsail/types.rb', line 2144

class ContactMethod < Struct.new(
  :contact_endpoint,
  :status,
  :protocol,
  :name,
  :arn,
  :created_at,
  :location,
  :resource_type,
  :support_code,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end