Class: Aws::Lightsail::Types::ContainerServiceDeployment
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::ContainerServiceDeployment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes a container deployment configuration of an Amazon Lightsail container service.
A deployment specifies the settings, such as the ports and launch command, of containers that are deployed to your container service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#containers ⇒ Hash<String,Types::Container>
An object that describes the configuration for the containers of the deployment.
-
#created_at ⇒ Time
The timestamp when the deployment was created.
-
#public_endpoint ⇒ Types::ContainerServiceEndpoint
An object that describes the endpoint of the deployment.
-
#state ⇒ String
The state of the deployment.
-
#version ⇒ Integer
The version number of the deployment.
Instance Attribute Details
#containers ⇒ Hash<String,Types::Container>
An object that describes the configuration for the containers of the deployment.
2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2461 class ContainerServiceDeployment < Struct.new( :version, :state, :containers, :public_endpoint, :created_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the deployment was created.
2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2461 class ContainerServiceDeployment < Struct.new( :version, :state, :containers, :public_endpoint, :created_at) SENSITIVE = [] include Aws::Structure end |
#public_endpoint ⇒ Types::ContainerServiceEndpoint
An object that describes the endpoint of the deployment.
2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2461 class ContainerServiceDeployment < Struct.new( :version, :state, :containers, :public_endpoint, :created_at) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the deployment.
A deployment can be in one of the following states:
-
ACTIVATING- The deployment is being created. -
ACTIVE- The deployment was successfully created, and it’s currently running on the container service. The container service can have only one deployment in an active state at a time. -
INACTIVE- The deployment was previously successfully created, but it is not currently running on the container service. -
FAILED- The deployment failed. Use theGetContainerLogaction to view the log events for the containers in the deployment to try to determine the reason for the failure.
2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2461 class ContainerServiceDeployment < Struct.new( :version, :state, :containers, :public_endpoint, :created_at) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version number of the deployment.
2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2461 class ContainerServiceDeployment < Struct.new( :version, :state, :containers, :public_endpoint, :created_at) SENSITIVE = [] include Aws::Structure end |