Class: Aws::Lightsail::Types::ContainerServicePower

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Describes the powers that can be specified for an Amazon Lightsail container service.

The power specifies the amount of RAM, the number of vCPUs, and the base price of the container service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cpu_countFloat

The number of vCPUs included in the power.

Returns:

  • (Float)


2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
# File 'lib/aws-sdk-lightsail/types.rb', line 2693

class ContainerServicePower < Struct.new(
  :power_id,
  :price,
  :cpu_count,
  :ram_size_in_gb,
  :name,
  :is_active)
  SENSITIVE = []
  include Aws::Structure
end

#is_activeBoolean

A Boolean value indicating whether the power is active and can be specified for container services.

Returns:

  • (Boolean)


2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
# File 'lib/aws-sdk-lightsail/types.rb', line 2693

class ContainerServicePower < Struct.new(
  :power_id,
  :price,
  :cpu_count,
  :ram_size_in_gb,
  :name,
  :is_active)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The friendly name of the power (nano).

Returns:

  • (String)


2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
# File 'lib/aws-sdk-lightsail/types.rb', line 2693

class ContainerServicePower < Struct.new(
  :power_id,
  :price,
  :cpu_count,
  :ram_size_in_gb,
  :name,
  :is_active)
  SENSITIVE = []
  include Aws::Structure
end

#power_idString

The ID of the power (nano-1).

Returns:

  • (String)


2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
# File 'lib/aws-sdk-lightsail/types.rb', line 2693

class ContainerServicePower < Struct.new(
  :power_id,
  :price,
  :cpu_count,
  :ram_size_in_gb,
  :name,
  :is_active)
  SENSITIVE = []
  include Aws::Structure
end

#priceFloat

The monthly price of the power in USD.

Returns:

  • (Float)


2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
# File 'lib/aws-sdk-lightsail/types.rb', line 2693

class ContainerServicePower < Struct.new(
  :power_id,
  :price,
  :cpu_count,
  :ram_size_in_gb,
  :name,
  :is_active)
  SENSITIVE = []
  include Aws::Structure
end

#ram_size_in_gbFloat

The amount of RAM (in GB) of the power.

Returns:

  • (Float)


2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
# File 'lib/aws-sdk-lightsail/types.rb', line 2693

class ContainerServicePower < Struct.new(
  :power_id,
  :price,
  :cpu_count,
  :ram_size_in_gb,
  :name,
  :is_active)
  SENSITIVE = []
  include Aws::Structure
end