Class: Aws::Lightsail::Types::CookieObject
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CookieObject
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes whether an Amazon Lightsail content delivery network (CDN) distribution forwards cookies to the origin and, if so, which ones.
For the cookies that you specify, your distribution caches separate versions of the specified content based on the cookie values in viewer requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cookies_allow_list ⇒ Array<String>
The specific cookies to forward to your distribution’s origin.
-
#option ⇒ String
Specifies which cookies to forward to the distribution’s origin for a cache behavior:
all,none, orallow-listto forward only the cookies specified in thecookiesAllowListparameter.
Instance Attribute Details
#cookies_allow_list ⇒ Array<String>
The specific cookies to forward to your distribution’s origin.
2831 2832 2833 2834 2835 2836 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2831 class CookieObject < Struct.new( :option, :cookies_allow_list) SENSITIVE = [] include Aws::Structure end |
#option ⇒ String
Specifies which cookies to forward to the distribution’s origin for a cache behavior: all, none, or allow-list to forward only the cookies specified in the cookiesAllowList parameter.
2831 2832 2833 2834 2835 2836 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2831 class CookieObject < Struct.new( :option, :cookies_allow_list) SENSITIVE = [] include Aws::Structure end |