Class: Aws::Lightsail::Types::CopySnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CopySnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#restore_date ⇒ String
The date of the source automatic snapshot to copy.
-
#source_region ⇒ String
The Amazon Web Services Region where the source manual or automatic snapshot is located.
-
#source_resource_name ⇒ String
The name of the source instance or disk from which the source automatic snapshot was created.
-
#source_snapshot_name ⇒ String
The name of the source manual snapshot to copy.
-
#target_snapshot_name ⇒ String
The name of the new manual snapshot to be created as a copy.
-
#use_latest_restorable_auto_snapshot ⇒ Boolean
A Boolean value to indicate whether to use the latest available automatic snapshot of the specified source instance or disk.
Instance Attribute Details
#restore_date ⇒ String
The date of the source automatic snapshot to copy. Use the get auto snapshots operation to identify the dates of the available
automatic snapshots.
Constraints:
-
Must be specified in
YYYY-MM-DDformat. -
This parameter cannot be defined together with the
use latest restorable auto snapshotparameter. Therestore dateanduse latest restorable auto snapshotparameters are mutually exclusive. -
Define this parameter only when copying an automatic snapshot as a manual snapshot. For more information, see the Amazon Lightsail Developer Guide.
2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2930 class CopySnapshotRequest < Struct.new( :source_snapshot_name, :source_resource_name, :restore_date, :use_latest_restorable_auto_snapshot, :target_snapshot_name, :source_region) SENSITIVE = [] include Aws::Structure end |
#source_region ⇒ String
The Amazon Web Services Region where the source manual or automatic snapshot is located.
2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2930 class CopySnapshotRequest < Struct.new( :source_snapshot_name, :source_resource_name, :restore_date, :use_latest_restorable_auto_snapshot, :target_snapshot_name, :source_region) SENSITIVE = [] include Aws::Structure end |
#source_resource_name ⇒ String
The name of the source instance or disk from which the source automatic snapshot was created.
Constraint:
- Define this parameter only when copying an automatic snapshot as a manual snapshot. For more information, see the Amazon Lightsail Developer Guide.
^
2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2930 class CopySnapshotRequest < Struct.new( :source_snapshot_name, :source_resource_name, :restore_date, :use_latest_restorable_auto_snapshot, :target_snapshot_name, :source_region) SENSITIVE = [] include Aws::Structure end |
#source_snapshot_name ⇒ String
The name of the source manual snapshot to copy.
Constraint:
- Define this parameter only when copying a manual snapshot as another manual snapshot.
^
2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2930 class CopySnapshotRequest < Struct.new( :source_snapshot_name, :source_resource_name, :restore_date, :use_latest_restorable_auto_snapshot, :target_snapshot_name, :source_region) SENSITIVE = [] include Aws::Structure end |
#target_snapshot_name ⇒ String
The name of the new manual snapshot to be created as a copy.
2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2930 class CopySnapshotRequest < Struct.new( :source_snapshot_name, :source_resource_name, :restore_date, :use_latest_restorable_auto_snapshot, :target_snapshot_name, :source_region) SENSITIVE = [] include Aws::Structure end |
#use_latest_restorable_auto_snapshot ⇒ Boolean
A Boolean value to indicate whether to use the latest available automatic snapshot of the specified source instance or disk.
Constraints:
-
This parameter cannot be defined together with the
restore dateparameter. Theuse latest restorable auto snapshotandrestore dateparameters are mutually exclusive. -
Define this parameter only when copying an automatic snapshot as a manual snapshot. For more information, see the Amazon Lightsail Developer Guide.
2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2930 class CopySnapshotRequest < Struct.new( :source_snapshot_name, :source_resource_name, :restore_date, :use_latest_restorable_auto_snapshot, :target_snapshot_name, :source_region) SENSITIVE = [] include Aws::Structure end |