Class: Aws::Lightsail::Types::CopySnapshotResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operationsArray<Types::Operation>

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.



2927
2928
2929
2930
2931
# File 'lib/aws-sdk-lightsail/types.rb', line 2927

class CopySnapshotResult < Struct.new(
  :operations)
  SENSITIVE = []
  include Aws::Structure
end