Class: Aws::Lightsail::Types::CreateBucketAccessKeyResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_keyTypes::AccessKey

An object that describes the access key that is created.



2990
2991
2992
2993
2994
2995
# File 'lib/aws-sdk-lightsail/types.rb', line 2990

class CreateBucketAccessKeyResult < Struct.new(
  :access_key,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end

#operationsArray<Types::Operation>

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.



2990
2991
2992
2993
2994
2995
# File 'lib/aws-sdk-lightsail/types.rb', line 2990

class CreateBucketAccessKeyResult < Struct.new(
  :access_key,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end