Class: Aws::Lightsail::Types::CreateBucketRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_nameString

The name for the bucket.

For more information about bucket names, see Bucket naming rules in Amazon Lightsail in the Amazon Lightsail Developer Guide.



3064
3065
3066
3067
3068
3069
3070
3071
# File 'lib/aws-sdk-lightsail/types.rb', line 3064

class CreateBucketRequest < Struct.new(
  :bucket_name,
  :bundle_id,
  :tags,
  :enable_object_versioning)
  SENSITIVE = []
  include Aws::Structure
end

#bundle_idString

The ID of the bundle to use for the bucket.

A bucket bundle specifies the monthly cost, storage space, and data transfer quota for a bucket.

Use the GetBucketBundles action to get a list of bundle IDs that you can specify.

Use the UpdateBucketBundle action to change the bundle after the bucket is created.



3064
3065
3066
3067
3068
3069
3070
3071
# File 'lib/aws-sdk-lightsail/types.rb', line 3064

class CreateBucketRequest < Struct.new(
  :bucket_name,
  :bundle_id,
  :tags,
  :enable_object_versioning)
  SENSITIVE = []
  include Aws::Structure
end

#enable_object_versioningBoolean

A Boolean value that indicates whether to enable versioning of objects in the bucket.

For more information about versioning, see Enabling and suspending object versioning in a bucket in Amazon Lightsail in the Amazon Lightsail Developer Guide.



3064
3065
3066
3067
3068
3069
3070
3071
# File 'lib/aws-sdk-lightsail/types.rb', line 3064

class CreateBucketRequest < Struct.new(
  :bucket_name,
  :bundle_id,
  :tags,
  :enable_object_versioning)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tag keys and optional values to add to the bucket during creation.

Use the TagResource action to tag the bucket after it's created.



3064
3065
3066
3067
3068
3069
3070
3071
# File 'lib/aws-sdk-lightsail/types.rb', line 3064

class CreateBucketRequest < Struct.new(
  :bucket_name,
  :bundle_id,
  :tags,
  :enable_object_versioning)
  SENSITIVE = []
  include Aws::Structure
end