Class: Aws::Lightsail::Types::CreateBucketResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateBucketResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ Types::Bucket
An object that describes the bucket that is created.
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#bucket ⇒ Types::Bucket
An object that describes the bucket that is created.
3074 3075 3076 3077 3078 3079 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3074 class CreateBucketResult < Struct.new( :bucket, :operations) SENSITIVE = [] include Aws::Structure end |
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
3074 3075 3076 3077 3078 3079 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3074 class CreateBucketResult < Struct.new( :bucket, :operations) SENSITIVE = [] include Aws::Structure end |