Class: Aws::Lightsail::Types::CreateCloudFormationStackResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateCloudFormationStackResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
3160 3161 3162 3163 3164 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3160 class CreateCloudFormationStackResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |