Class: Aws::Lightsail::Types::CreateContactMethodResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateContactMethodResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
3241 3242 3243 3244 3245 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3241 class CreateContactMethodResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |