Class: Aws::Lightsail::Types::CreateContainerServiceRegistryLoginResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateContainerServiceRegistryLoginResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#registry_login ⇒ Types::ContainerServiceRegistryLogin
An object that describes the log in information for the container service registry of your Lightsail account.
Instance Attribute Details
#registry_login ⇒ Types::ContainerServiceRegistryLogin
An object that describes the log in information for the container service registry of your Lightsail account.
3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3278 class CreateContainerServiceRegistryLoginResult < Struct.new( :registry_login) SENSITIVE = [] include Aws::Structure end |