Class: Aws::Lightsail::Types::CreateDiskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_onsArray<Types::AddOnRequest>

An array of objects that represent the add-ons to enable for the new disk.



3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-lightsail/types.rb', line 3604

class CreateDiskRequest < Struct.new(
  :disk_name,
  :availability_zone,
  :size_in_gb,
  :tags,
  :add_ons)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone where you want to create the disk (us-east-2a). Use the same Availability Zone as the Lightsail instance to which you want to attach the disk.

Use the ‘get regions` operation to list the Availability Zones where Lightsail is currently available.



3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-lightsail/types.rb', line 3604

class CreateDiskRequest < Struct.new(
  :disk_name,
  :availability_zone,
  :size_in_gb,
  :tags,
  :add_ons)
  SENSITIVE = []
  include Aws::Structure
end

#disk_nameString

The unique Lightsail disk name (my-disk).



3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-lightsail/types.rb', line 3604

class CreateDiskRequest < Struct.new(
  :disk_name,
  :availability_zone,
  :size_in_gb,
  :tags,
  :add_ons)
  SENSITIVE = []
  include Aws::Structure
end

#size_in_gbInteger

The size of the disk in GB (32).



3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-lightsail/types.rb', line 3604

class CreateDiskRequest < Struct.new(
  :disk_name,
  :availability_zone,
  :size_in_gb,
  :tags,
  :add_ons)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tag keys and optional values to add to the resource during create.

Use the TagResource action to tag a resource after it’s created.



3604
3605
3606
3607
3608
3609
3610
3611
3612
# File 'lib/aws-sdk-lightsail/types.rb', line 3604

class CreateDiskRequest < Struct.new(
  :disk_name,
  :availability_zone,
  :size_in_gb,
  :tags,
  :add_ons)
  SENSITIVE = []
  include Aws::Structure
end