Class: Aws::Lightsail::Types::CreateDistributionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateDistributionResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distribution ⇒ Types::LightsailDistribution
An object that describes the distribution created.
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#distribution ⇒ Types::LightsailDistribution
An object that describes the distribution created.
3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3785 class CreateDistributionResult < Struct.new( :distribution, :operation) SENSITIVE = [] include Aws::Structure end |
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3785 class CreateDistributionResult < Struct.new( :distribution, :operation) SENSITIVE = [] include Aws::Structure end |