Class: Aws::Lightsail::Types::CreateDomainEntryResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operationTypes::Operation

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.



3819
3820
3821
3822
3823
# File 'lib/aws-sdk-lightsail/types.rb', line 3819

class CreateDomainEntryResult < Struct.new(
  :operation)
  SENSITIVE = []
  include Aws::Structure
end