Class: Aws::Lightsail::Types::CreateKeyPairResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_pairTypes::KeyPair

An array of key-value pairs containing information about the new key pair you just created.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
# File 'lib/aws-sdk-lightsail/types.rb', line 4277

class CreateKeyPairResult < Struct.new(
  :key_pair,
  :public_key_base_64,
  :private_key_base_64,
  :operation)
  SENSITIVE = []
  include Aws::Structure
end

#operationTypes::Operation

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.

Returns:



4277
4278
4279
4280
4281
4282
4283
4284
# File 'lib/aws-sdk-lightsail/types.rb', line 4277

class CreateKeyPairResult < Struct.new(
  :key_pair,
  :public_key_base_64,
  :private_key_base_64,
  :operation)
  SENSITIVE = []
  include Aws::Structure
end

#private_key_base_64String

A base64-encoded RSA private key.

Returns:

  • (String)


4277
4278
4279
4280
4281
4282
4283
4284
# File 'lib/aws-sdk-lightsail/types.rb', line 4277

class CreateKeyPairResult < Struct.new(
  :key_pair,
  :public_key_base_64,
  :private_key_base_64,
  :operation)
  SENSITIVE = []
  include Aws::Structure
end

#public_key_base_64String

A base64-encoded public key of the ssh-rsa type.

Returns:

  • (String)


4277
4278
4279
4280
4281
4282
4283
4284
# File 'lib/aws-sdk-lightsail/types.rb', line 4277

class CreateKeyPairResult < Struct.new(
  :key_pair,
  :public_key_base_64,
  :private_key_base_64,
  :operation)
  SENSITIVE = []
  include Aws::Structure
end