Class: Aws::Lightsail::Types::CreateLoadBalancerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateLoadBalancerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_alternative_names ⇒ Array<String>
The optional alternative domains and subdomains to use with your SSL/TLS certificate (
www.example.com,example.com,m.example.com,blog.example.com). -
#certificate_domain_name ⇒ String
The domain name with which your certificate is associated (
example.com). -
#certificate_name ⇒ String
The name of the SSL/TLS certificate.
-
#health_check_path ⇒ String
The path you provided to perform the load balancer health check.
-
#instance_port ⇒ Integer
The instance port where you’re creating your load balancer.
-
#ip_address_type ⇒ String
The IP address type for the load balancer.
-
#load_balancer_name ⇒ String
The name of your load balancer.
-
#tags ⇒ Array<Types::Tag>
The tag keys and optional values to add to the resource during create.
-
#tls_policy_name ⇒ String
The name of the TLS policy to apply to the load balancer.
Instance Attribute Details
#certificate_alternative_names ⇒ Array<String>
The optional alternative domains and subdomains to use with your SSL/TLS certificate (www.example.com, example.com, m.example.com, blog.example.com).
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4359 class CreateLoadBalancerRequest < Struct.new( :load_balancer_name, :instance_port, :health_check_path, :certificate_name, :certificate_domain_name, :certificate_alternative_names, :tags, :ip_address_type, :tls_policy_name) SENSITIVE = [] include Aws::Structure end |
#certificate_domain_name ⇒ String
The domain name with which your certificate is associated (example.com).
If you specify certificateDomainName, then certificateName is required (and vice-versa).
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4359 class CreateLoadBalancerRequest < Struct.new( :load_balancer_name, :instance_port, :health_check_path, :certificate_name, :certificate_domain_name, :certificate_alternative_names, :tags, :ip_address_type, :tls_policy_name) SENSITIVE = [] include Aws::Structure end |
#certificate_name ⇒ String
The name of the SSL/TLS certificate.
If you specify certificateName, then certificateDomainName is required (and vice-versa).
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4359 class CreateLoadBalancerRequest < Struct.new( :load_balancer_name, :instance_port, :health_check_path, :certificate_name, :certificate_domain_name, :certificate_alternative_names, :tags, :ip_address_type, :tls_policy_name) SENSITIVE = [] include Aws::Structure end |
#health_check_path ⇒ String
The path you provided to perform the load balancer health check. If you didn’t specify a health check path, Lightsail uses the root path of your website (‘“/”`).
You may want to specify a custom health check path other than the root of your application if your home page loads slowly or has a lot of media or scripting on it.
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4359 class CreateLoadBalancerRequest < Struct.new( :load_balancer_name, :instance_port, :health_check_path, :certificate_name, :certificate_domain_name, :certificate_alternative_names, :tags, :ip_address_type, :tls_policy_name) SENSITIVE = [] include Aws::Structure end |
#instance_port ⇒ Integer
The instance port where you’re creating your load balancer.
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4359 class CreateLoadBalancerRequest < Struct.new( :load_balancer_name, :instance_port, :health_check_path, :certificate_name, :certificate_domain_name, :certificate_alternative_names, :tags, :ip_address_type, :tls_policy_name) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type for the load balancer.
The possible values are ipv4 for IPv4 only, ipv6 for IPv6 only, and dualstack for IPv4 and IPv6.
The default value is dualstack.
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4359 class CreateLoadBalancerRequest < Struct.new( :load_balancer_name, :instance_port, :health_check_path, :certificate_name, :certificate_domain_name, :certificate_alternative_names, :tags, :ip_address_type, :tls_policy_name) SENSITIVE = [] include Aws::Structure end |
#load_balancer_name ⇒ String
The name of your load balancer.
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4359 class CreateLoadBalancerRequest < Struct.new( :load_balancer_name, :instance_port, :health_check_path, :certificate_name, :certificate_domain_name, :certificate_alternative_names, :tags, :ip_address_type, :tls_policy_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tag keys and optional values to add to the resource during create.
Use the TagResource action to tag a resource after it’s created.
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4359 class CreateLoadBalancerRequest < Struct.new( :load_balancer_name, :instance_port, :health_check_path, :certificate_name, :certificate_domain_name, :certificate_alternative_names, :tags, :ip_address_type, :tls_policy_name) SENSITIVE = [] include Aws::Structure end |
#tls_policy_name ⇒ String
The name of the TLS policy to apply to the load balancer.
Use the [GetLoadBalancerTlsPolicies][1] action to get a list of TLS policy names that you can specify.
For more information about load balancer TLS policies, see [Configuring TLS security policies on your Amazon Lightsail load balancers][2] in the *Amazon Lightsail Developer Guide*.
[1]: docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetLoadBalancerTlsPolicies.html [2]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-configure-load-balancer-tls-security-policy
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4359 class CreateLoadBalancerRequest < Struct.new( :load_balancer_name, :instance_port, :health_check_path, :certificate_name, :certificate_domain_name, :certificate_alternative_names, :tags, :ip_address_type, :tls_policy_name) SENSITIVE = [] include Aws::Structure end |