Class: Aws::Lightsail::Types::CreateLoadBalancerResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateLoadBalancerResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
4426 4427 4428 4429 4430 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4426 class CreateLoadBalancerResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |