Class: Aws::Lightsail::Types::CreateRelationalDatabaseSnapshotResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateRelationalDatabaseSnapshotResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
4844 4845 4846 4847 4848 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4844 class CreateRelationalDatabaseSnapshotResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |