Class: Aws::Lightsail::Types::DeleteBucketAccessKeyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteBucketAccessKeyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_key_id ⇒ String
The ID of the access key to delete.
-
#bucket_name ⇒ String
The name of the bucket that the access key belongs to.
Instance Attribute Details
#access_key_id ⇒ String
The ID of the access key to delete.
Use the [GetBucketAccessKeys][1] action to get a list of access key IDs that you can specify.
[1]: docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBucketAccessKeys.html
4927 4928 4929 4930 4931 4932 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4927 class DeleteBucketAccessKeyRequest < Struct.new( :bucket_name, :access_key_id) SENSITIVE = [] include Aws::Structure end |
#bucket_name ⇒ String
The name of the bucket that the access key belongs to.
4927 4928 4929 4930 4931 4932 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4927 class DeleteBucketAccessKeyRequest < Struct.new( :bucket_name, :access_key_id) SENSITIVE = [] include Aws::Structure end |