Class: Aws::Lightsail::Types::DeleteBucketAccessKeyResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteBucketAccessKeyResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
4942 4943 4944 4945 4946 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4942 class DeleteBucketAccessKeyResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |