Class: Aws::Lightsail::Types::DeleteContactMethodRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#protocolString

The protocol that will be deleted, such as Email or SMS (text messaging).

To delete an Email and an SMS contact method if you added both, you must run separate DeleteContactMethod actions to delete each protocol.

Returns:

  • (String)


5093
5094
5095
5096
5097
# File 'lib/aws-sdk-lightsail/types.rb', line 5093

class DeleteContactMethodRequest < Struct.new(
  :protocol)
  SENSITIVE = []
  include Aws::Structure
end