Class: Aws::Lightsail::Types::DeleteContactMethodResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteContactMethodResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5107 5108 5109 5110 5111 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5107 class DeleteContactMethodResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |