Class: Aws::Lightsail::Types::DeleteDiskResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteDiskResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5189 5190 5191 5192 5193 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5189 class DeleteDiskResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |