Class: Aws::Lightsail::Types::DeleteDiskSnapshotResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteDiskSnapshotResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5216 5217 5218 5219 5220 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5216 class DeleteDiskSnapshotResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |