Class: Aws::Lightsail::Types::DeleteDistributionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteDistributionResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An object that describes the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An object that describes the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5245 5246 5247 5248 5249 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5245 class DeleteDistributionResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |