Class: Aws::Lightsail::Types::DeleteDomainEntryResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operationTypes::Operation

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.



5277
5278
5279
5280
5281
# File 'lib/aws-sdk-lightsail/types.rb', line 5277

class DeleteDomainEntryResult < Struct.new(
  :operation)
  SENSITIVE = []
  include Aws::Structure
end