Class: Aws::Lightsail::Types::DeleteInstanceResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operationsArray<Types::Operation>

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.



5335
5336
5337
5338
5339
# File 'lib/aws-sdk-lightsail/types.rb', line 5335

class DeleteInstanceResult < Struct.new(
  :operations)
  SENSITIVE = []
  include Aws::Structure
end