Class: Aws::Lightsail::Types::DeleteInstanceSnapshotResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteInstanceSnapshotResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5361 5362 5363 5364 5365 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5361 class DeleteInstanceSnapshotResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |