Class: Aws::Lightsail::Types::DeleteKeyPairRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteKeyPairRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_fingerprint ⇒ String
The RSA fingerprint of the Lightsail default key pair to delete.
-
#key_pair_name ⇒ String
The name of the key pair to delete.
Instance Attribute Details
#expected_fingerprint ⇒ String
The RSA fingerprint of the Lightsail default key pair to delete.
<note markdown=“1”> The expectedFingerprint parameter is required only when specifying to delete a Lightsail default key pair.
</note>
5337 5338 5339 5340 5341 5342 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5337 class DeleteKeyPairRequest < Struct.new( :key_pair_name, :expected_fingerprint) SENSITIVE = [] include Aws::Structure end |
#key_pair_name ⇒ String
The name of the key pair to delete.
5337 5338 5339 5340 5341 5342 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5337 class DeleteKeyPairRequest < Struct.new( :key_pair_name, :expected_fingerprint) SENSITIVE = [] include Aws::Structure end |