Class: Aws::Lightsail::Types::DeleteKeyPairResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteKeyPairResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5397 5398 5399 5400 5401 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5397 class DeleteKeyPairResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |