Class: Aws::Lightsail::Types::DeleteLoadBalancerResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteLoadBalancerResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5450 5451 5452 5453 5454 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5450 class DeleteLoadBalancerResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |