Class: Aws::Lightsail::Types::DeleteLoadBalancerTlsCertificateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteLoadBalancerTlsCertificateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_name ⇒ String
The SSL/TLS certificate name.
-
#force ⇒ Boolean
When
true, forces the deletion of an SSL/TLS certificate. -
#load_balancer_name ⇒ String
The load balancer name.
Instance Attribute Details
#certificate_name ⇒ String
The SSL/TLS certificate name.
5430 5431 5432 5433 5434 5435 5436 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5430 class DeleteLoadBalancerTlsCertificateRequest < Struct.new( :load_balancer_name, :certificate_name, :force) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
When true, forces the deletion of an SSL/TLS certificate.
There can be two certificates associated with a Lightsail load balancer: the primary and the backup. The force parameter is required when the primary SSL/TLS certificate is in use by an instance attached to the load balancer.
5430 5431 5432 5433 5434 5435 5436 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5430 class DeleteLoadBalancerTlsCertificateRequest < Struct.new( :load_balancer_name, :certificate_name, :force) SENSITIVE = [] include Aws::Structure end |
#load_balancer_name ⇒ String
The load balancer name.
5430 5431 5432 5433 5434 5435 5436 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5430 class DeleteLoadBalancerTlsCertificateRequest < Struct.new( :load_balancer_name, :certificate_name, :force) SENSITIVE = [] include Aws::Structure end |