Class: Aws::Lightsail::Types::DetachInstancesFromLoadBalancerResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DetachInstancesFromLoadBalancerResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5680 5681 5682 5683 5684 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5680 class DetachInstancesFromLoadBalancerResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |