Class: Aws::Lightsail::Types::DisableAddOnResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DisableAddOnResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5737 5738 5739 5740 5741 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5737 class DisableAddOnResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |