Class: Aws::Lightsail::Types::DiskMap
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DiskMap
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes a block storage disk mapping.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#new_disk_name ⇒ String
The new disk name (
my-new-disk). -
#original_disk_path ⇒ String
The original disk path exposed to the instance (for example,
/dev/sdh).
Instance Attribute Details
#new_disk_name ⇒ String
The new disk name (my-new-disk).
5865 5866 5867 5868 5869 5870 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5865 class DiskMap < Struct.new( :original_disk_path, :new_disk_name) SENSITIVE = [] include Aws::Structure end |
#original_disk_path ⇒ String
The original disk path exposed to the instance (for example, /dev/sdh).
5865 5866 5867 5868 5869 5870 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5865 class DiskMap < Struct.new( :original_disk_path, :new_disk_name) SENSITIVE = [] include Aws::Structure end |