Class: Aws::Lightsail::Types::DiskSnapshot

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Describes a block storage disk snapshot.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the disk snapshot.

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date when the disk snapshot was created.

Returns:

  • (Time)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#from_disk_arnString

The Amazon Resource Name (ARN) of the source disk from which the disk snapshot was created.

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#from_disk_nameString

The unique name of the source disk from which the disk snapshot was created.

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#from_instance_arnString

The Amazon Resource Name (ARN) of the source instance from which the disk (system volume) snapshot was created.

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#from_instance_nameString

The unique name of the source instance from which the disk (system volume) snapshot was created.

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#is_from_auto_snapshotBoolean

A Boolean value indicating whether the snapshot was created from an automatic snapshot.

Returns:

  • (Boolean)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::ResourceLocation

The AWS Region and Availability Zone where the disk snapshot was created.



5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the disk snapshot (my-disk-snapshot).

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#progressString

The progress of the snapshot.

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The Lightsail resource type (DiskSnapshot).

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#size_in_gbInteger

The size of the disk in GB.

Returns:

  • (Integer)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The status of the disk snapshot operation.

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#support_codeString

The support code. Include this code in your email to support when you have questions about an instance or another resource in Lightsail. This code enables our support team to look up your Lightsail information more easily.

Returns:

  • (String)


5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tag keys and optional values for the resource. For more information about tags in Lightsail, see the Amazon Lightsail Developer Guide.

Returns:



5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/aws-sdk-lightsail/types.rb', line 5996

class DiskSnapshot < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :size_in_gb,
  :state,
  :progress,
  :from_disk_name,
  :from_disk_arn,
  :from_instance_name,
  :from_instance_arn,
  :is_from_auto_snapshot)
  SENSITIVE = []
  include Aws::Structure
end