Class: Aws::Lightsail::Types::DistributionCustomErrorResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Describes a custom error response for a Lightsail distribution. A custom error response specifies the page that the distribution returns to the viewer. It also specifies the HTTP status code that the distribution sends when the origin responds with a given HTTP error code.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_caching_min_ttlInteger

The minimum time, in seconds, that the distribution caches the custom error response before requesting the object again from the origin. If you don't specify a value, the default is 10 seconds.

Returns:



6096
6097
6098
6099
6100
6101
6102
6103
# File 'lib/aws-sdk-lightsail/types.rb', line 6096

class DistributionCustomErrorResponse < Struct.new(
  :error_code,
  :response_code,
  :response_page_path,
  :error_caching_min_ttl)
  SENSITIVE = []
  include Aws::Structure
end

#error_codeInteger

The HTTP error code from the origin that triggers the custom error response (for example, 403 or 404).

Returns:



6096
6097
6098
6099
6100
6101
6102
6103
# File 'lib/aws-sdk-lightsail/types.rb', line 6096

class DistributionCustomErrorResponse < Struct.new(
  :error_code,
  :response_code,
  :response_page_path,
  :error_caching_min_ttl)
  SENSITIVE = []
  include Aws::Structure
end

#response_codeString

The HTTP status code that the distribution returns to the viewer for the custom error response.

Returns:



6096
6097
6098
6099
6100
6101
6102
6103
# File 'lib/aws-sdk-lightsail/types.rb', line 6096

class DistributionCustomErrorResponse < Struct.new(
  :error_code,
  :response_code,
  :response_page_path,
  :error_caching_min_ttl)
  SENSITIVE = []
  include Aws::Structure
end

#response_page_pathString

The path to the custom error page that the distribution returns to the viewer (for example, /404.html). The path must begin with a forward slash (/) and reference an object that is available from the origin.

Returns:



6096
6097
6098
6099
6100
6101
6102
6103
# File 'lib/aws-sdk-lightsail/types.rb', line 6096

class DistributionCustomErrorResponse < Struct.new(
  :error_code,
  :response_code,
  :response_page_path,
  :error_caching_min_ttl)
  SENSITIVE = []
  include Aws::Structure
end