Class: Aws::Lightsail::Types::Domain
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::Domain
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes a domain where you are storing recordsets.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the domain recordset (
arn:aws:lightsail:global:123456789101:Domain/824cede0-abc7-4f84-8dbc-12345EXAMPLE). -
#created_at ⇒ Time
The date when the domain recordset was created.
-
#domain_entries ⇒ Array<Types::DomainEntry>
An array of key-value pairs containing information about the domain entries.
-
#location ⇒ Types::ResourceLocation
The AWS Region and Availability Zones where the domain recordset was created.
-
#name ⇒ String
The name of the domain.
-
#registered_domain_delegation_info ⇒ Types::RegisteredDomainDelegationInfo
An object that describes the state of the Route 53 domain delegation to a Lightsail DNS zone.
-
#resource_type ⇒ String
The resource type.
-
#support_code ⇒ String
The support code.
-
#tags ⇒ Array<Types::Tag>
The tag keys and optional values for the resource.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the domain recordset
(arn:aws:lightsail:global:123456789101:Domain/824cede0-abc7-4f84-8dbc-12345EXAMPLE).
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6204 class Domain < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :domain_entries, :registered_domain_delegation_info) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date when the domain recordset was created.
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6204 class Domain < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :domain_entries, :registered_domain_delegation_info) SENSITIVE = [] include Aws::Structure end |
#domain_entries ⇒ Array<Types::DomainEntry>
An array of key-value pairs containing information about the domain entries.
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6204 class Domain < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :domain_entries, :registered_domain_delegation_info) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::ResourceLocation
The AWS Region and Availability Zones where the domain recordset was created.
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6204 class Domain < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :domain_entries, :registered_domain_delegation_info) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the domain.
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6204 class Domain < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :domain_entries, :registered_domain_delegation_info) SENSITIVE = [] include Aws::Structure end |
#registered_domain_delegation_info ⇒ Types::RegisteredDomainDelegationInfo
An object that describes the state of the Route 53 domain delegation to a Lightsail DNS zone.
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6204 class Domain < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :domain_entries, :registered_domain_delegation_info) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type.
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6204 class Domain < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :domain_entries, :registered_domain_delegation_info) SENSITIVE = [] include Aws::Structure end |
#support_code ⇒ String
The support code. Include this code in your email to support when you have questions about an instance or another resource in Lightsail. This code enables our support team to look up your Lightsail information more easily.
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6204 class Domain < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :domain_entries, :registered_domain_delegation_info) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tag keys and optional values for the resource. For more information about tags in Lightsail, see the Amazon Lightsail Developer Guide.
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6204 class Domain < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :domain_entries, :registered_domain_delegation_info) SENSITIVE = [] include Aws::Structure end |