Class: Aws::Lightsail::Types::EnableAddOnResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::EnableAddOnResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6388 class EnableAddOnResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |