Class: Aws::Lightsail::Types::GetActiveNamesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetActiveNamesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_names ⇒ Array<String>
The list of active names returned by the get active names request.
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#active_names ⇒ Array<String>
The list of active names returned by the get active names request.
6621 6622 6623 6624 6625 6626 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6621 class GetActiveNamesResult < Struct.new( :active_names, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetActiveNames
request and specify the next page token using the pageToken
parameter.
6621 6622 6623 6624 6625 6626 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6621 class GetActiveNamesResult < Struct.new( :active_names, :next_page_token) SENSITIVE = [] include Aws::Structure end |