Class: Aws::Lightsail::Types::GetBlueprintsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_categoryString

Returns a list of blueprints that are specific to Lightsail for Research.

You must use this parameter to view Lightsail for Research blueprints.



6743
6744
6745
6746
6747
6748
6749
# File 'lib/aws-sdk-lightsail/types.rb', line 6743

class GetBlueprintsRequest < Struct.new(
  :include_inactive,
  :page_token,
  :app_category)
  SENSITIVE = []
  include Aws::Structure
end

#include_inactiveBoolean

A Boolean value that indicates whether to include inactive (unavailable) blueprints in the response of your request.



6743
6744
6745
6746
6747
6748
6749
# File 'lib/aws-sdk-lightsail/types.rb', line 6743

class GetBlueprintsRequest < Struct.new(
  :include_inactive,
  :page_token,
  :app_category)
  SENSITIVE = []
  include Aws::Structure
end

#page_tokenString

The token to advance to the next page of results from your request.

To get a page token, perform an initial GetBlueprints request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request.



6743
6744
6745
6746
6747
6748
6749
# File 'lib/aws-sdk-lightsail/types.rb', line 6743

class GetBlueprintsRequest < Struct.new(
  :include_inactive,
  :page_token,
  :app_category)
  SENSITIVE = []
  include Aws::Structure
end