Class: Aws::Lightsail::Types::GetBucketsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetBucketsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The name of the bucket for which to return information.
-
#include_connected_resources ⇒ Boolean
A Boolean value that indicates whether to include Lightsail instances that were given access to the bucket using the [SetResourceAccessForBucket][1] action.
-
#include_cors ⇒ Boolean
A Boolean value that indicates whether to include Lightsail bucket CORS configuration in the response.
-
#page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#bucket_name ⇒ String
The name of the bucket for which to return information.
When omitted, the response includes all of your buckets in the Amazon Web Services Region where the request is made.
6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6989 class GetBucketsRequest < Struct.new( :bucket_name, :page_token, :include_connected_resources, :include_cors) SENSITIVE = [] include Aws::Structure end |
#include_connected_resources ⇒ Boolean
A Boolean value that indicates whether to include Lightsail instances that were given access to the bucket using the SetResourceAccessForBucket action.
6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6989 class GetBucketsRequest < Struct.new( :bucket_name, :page_token, :include_connected_resources, :include_cors) SENSITIVE = [] include Aws::Structure end |
#include_cors ⇒ Boolean
A Boolean value that indicates whether to include Lightsail bucket CORS configuration in the response. For more information, see Configuring cross-origin resource sharing (CORS).
bucketName specified. The default value for this parameter is
False.
6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6989 class GetBucketsRequest < Struct.new( :bucket_name, :page_token, :include_connected_resources, :include_cors) SENSITIVE = [] include Aws::Structure end |
#page_token ⇒ String
The token to advance to the next page of results from your request.
To get a page token, perform an initial GetBuckets request. If
your results are paginated, the response will return a next page
token that you can specify as the page token in a subsequent
request.
6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6989 class GetBucketsRequest < Struct.new( :bucket_name, :page_token, :include_connected_resources, :include_cors) SENSITIVE = [] include Aws::Structure end |