Class: Aws::Lightsail::Types::GetBucketsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetBucketsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_level_bpa_sync ⇒ Types::AccountLevelBpaSync
An object that describes the synchronization status of the Amazon S3 account-level block public access feature for your Lightsail buckets.
-
#buckets ⇒ Array<Types::Bucket>
An array of objects that describe buckets.
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#account_level_bpa_sync ⇒ Types::AccountLevelBpaSync
An object that describes the synchronization status of the Amazon S3 account-level block public access feature for your Lightsail buckets.
For more information about this feature and how it affects Lightsail buckets, see Block public access for buckets in Amazon Lightsail.
7029 7030 7031 7032 7033 7034 7035 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7029 class GetBucketsResult < Struct.new( :buckets, :next_page_token, :account_level_bpa_sync) SENSITIVE = [] include Aws::Structure end |
#buckets ⇒ Array<Types::Bucket>
An array of objects that describe buckets.
7029 7030 7031 7032 7033 7034 7035 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7029 class GetBucketsResult < Struct.new( :buckets, :next_page_token, :account_level_bpa_sync) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetBuckets
request and specify the next page token using the pageToken
parameter.
7029 7030 7031 7032 7033 7034 7035 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7029 class GetBucketsResult < Struct.new( :buckets, :next_page_token, :account_level_bpa_sync) SENSITIVE = [] include Aws::Structure end |