Class: Aws::Lightsail::Types::GetCloudFormationStackRecordsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetCloudFormationStackRecordsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_formation_stack_records ⇒ Array<Types::CloudFormationStackRecord>
A list of objects describing the CloudFormation stack records.
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#cloud_formation_stack_records ⇒ Array<Types::CloudFormationStackRecord>
A list of objects describing the CloudFormation stack records.
7089 7090 7091 7092 7093 7094 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7089 class GetCloudFormationStackRecordsResult < Struct.new( :cloud_formation_stack_records, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another ‘GetCloudFormationStackRecords` request and specify the next page token using the `pageToken` parameter.
7089 7090 7091 7092 7093 7094 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7089 class GetCloudFormationStackRecordsResult < Struct.new( :cloud_formation_stack_records, :next_page_token) SENSITIVE = [] include Aws::Structure end |