Class: Aws::Lightsail::Types::GetContainerLogResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetContainerLogResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_events ⇒ Array<Types::ContainerServiceLogEvent>
An array of objects that describe the log events of a container.
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#log_events ⇒ Array<Types::ContainerServiceLogEvent>
An array of objects that describe the log events of a container.
7298 7299 7300 7301 7302 7303 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7298 class GetContainerLogResult < Struct.new( :log_events, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetContainerLog request and specify the next page token using the pageToken parameter.
7298 7299 7300 7301 7302 7303 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7298 class GetContainerLogResult < Struct.new( :log_events, :next_page_token) SENSITIVE = [] include Aws::Structure end |