Class: Aws::Lightsail::Types::GetDiskSnapshotsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#disk_snapshotsArray<Types::DiskSnapshot>

An array of objects containing information about all block storage disk snapshots.

Returns:



7703
7704
7705
7706
7707
7708
# File 'lib/aws-sdk-lightsail/types.rb', line 7703

class GetDiskSnapshotsResult < Struct.new(
  :disk_snapshots,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_page_tokenString

The token to advance to the next page of results from your request.

A next page token is not returned if there are no more results to display.

To get the next page of results, perform another GetDiskSnapshots request and specify the next page token using the pageToken parameter.

Returns:

  • (String)


7703
7704
7705
7706
7707
7708
# File 'lib/aws-sdk-lightsail/types.rb', line 7703

class GetDiskSnapshotsResult < Struct.new(
  :disk_snapshots,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end