Class: Aws::Lightsail::Types::GetDisksResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#disksArray<Types::Disk>

An array of objects containing information about all block storage disks.

Returns:



7743
7744
7745
7746
7747
7748
# File 'lib/aws-sdk-lightsail/types.rb', line 7743

class GetDisksResult < Struct.new(
  :disks,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_page_tokenString

The token to advance to the next page of results from your request.

A next page token is not returned if there are no more results to display.

To get the next page of results, perform another GetDisks request and specify the next page token using the pageToken parameter.

Returns:

  • (String)


7743
7744
7745
7746
7747
7748
# File 'lib/aws-sdk-lightsail/types.rb', line 7743

class GetDisksResult < Struct.new(
  :disks,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end