Class: Aws::Lightsail::Types::GetDistributionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetDistributionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distribution_name ⇒ String
The name of the distribution for which to return information.
-
#page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#distribution_name ⇒ String
The name of the distribution for which to return information.
When omitted, the response includes all of your distributions in the Amazon Web Services Region where the request is made.
8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-lightsail/types.rb', line 8000 class GetDistributionsRequest < Struct.new( :distribution_name, :page_token) SENSITIVE = [] include Aws::Structure end |
#page_token ⇒ String
The token to advance to the next page of results from your request.
To get a page token, perform an initial GetDistributions request.
If your results are paginated, the response will return a next page
token that you can specify as the page token in a subsequent
request.
8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-lightsail/types.rb', line 8000 class GetDistributionsRequest < Struct.new( :distribution_name, :page_token) SENSITIVE = [] include Aws::Structure end |