Class: Aws::Lightsail::Types::GetDistributionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetDistributionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distributions ⇒ Array<Types::LightsailDistribution>
An array of objects that describe your distributions.
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#distributions ⇒ Array<Types::LightsailDistribution>
An array of objects that describe your distributions.
7939 7940 7941 7942 7943 7944 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7939 class GetDistributionsResult < Struct.new( :distributions, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetDistributions request and specify the next page token using the pageToken parameter.
7939 7940 7941 7942 7943 7944 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7939 class GetDistributionsResult < Struct.new( :distributions, :next_page_token) SENSITIVE = [] include Aws::Structure end |