Class: Aws::Lightsail::Types::GetExportSnapshotRecordsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#export_snapshot_recordsArray<Types::ExportSnapshotRecord>

A list of objects describing the export snapshot records.

Returns:



8028
8029
8030
8031
8032
8033
# File 'lib/aws-sdk-lightsail/types.rb', line 8028

class GetExportSnapshotRecordsResult < Struct.new(
  :export_snapshot_records,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_page_tokenString

The token to advance to the next page of results from your request.

A next page token is not returned if there are no more results to display.

To get the next page of results, perform another ‘GetExportSnapshotRecords` request and specify the next page token using the `pageToken` parameter.

Returns:

  • (String)


8028
8029
8030
8031
8032
8033
# File 'lib/aws-sdk-lightsail/types.rb', line 8028

class GetExportSnapshotRecordsResult < Struct.new(
  :export_snapshot_records,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end