Class: Aws::Lightsail::Types::GetInstancesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instancesArray<Types::Instance>

An array of key-value pairs containing information about your instances.

Returns:



8549
8550
8551
8552
8553
8554
# File 'lib/aws-sdk-lightsail/types.rb', line 8549

class GetInstancesResult < Struct.new(
  :instances,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_page_tokenString

The token to advance to the next page of results from your request.

A next page token is not returned if there are no more results to display.

To get the next page of results, perform another GetInstances request and specify the next page token using the pageToken parameter.

Returns:



8549
8550
8551
8552
8553
8554
# File 'lib/aws-sdk-lightsail/types.rb', line 8549

class GetInstancesResult < Struct.new(
  :instances,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end