Class: Aws::Lightsail::Types::GetKeyPairsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetKeyPairsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key_pairs ⇒ Array<Types::KeyPair>
An array of key-value pairs containing information about the key pairs.
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#key_pairs ⇒ Array<Types::KeyPair>
An array of key-value pairs containing information about the key pairs.
8537 8538 8539 8540 8541 8542 |
# File 'lib/aws-sdk-lightsail/types.rb', line 8537 class GetKeyPairsResult < Struct.new( :key_pairs, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetKeyPairs request and specify the next page token using the pageToken parameter.
8537 8538 8539 8540 8541 8542 |
# File 'lib/aws-sdk-lightsail/types.rb', line 8537 class GetKeyPairsResult < Struct.new( :key_pairs, :next_page_token) SENSITIVE = [] include Aws::Structure end |