Class: Aws::Lightsail::Types::GetLoadBalancerTlsPoliciesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetLoadBalancerTlsPoliciesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
-
#tls_policies ⇒ Array<Types::LoadBalancerTlsPolicy>
An array of objects that describe the TLS security policies that are available.
Instance Attribute Details
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another
GetLoadBalancerTlsPolicies request and specify the next page token
using the pageToken parameter.
8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-lightsail/types.rb', line 8919 class GetLoadBalancerTlsPoliciesResult < Struct.new( :tls_policies, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#tls_policies ⇒ Array<Types::LoadBalancerTlsPolicy>
An array of objects that describe the TLS security policies that are available.
8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-lightsail/types.rb', line 8919 class GetLoadBalancerTlsPoliciesResult < Struct.new( :tls_policies, :next_page_token) SENSITIVE = [] include Aws::Structure end |