Class: Aws::Lightsail::Types::GetOperationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetOperationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetOperations request and specify the next page token using the pageToken parameter.
9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9003 class GetOperationsResult < Struct.new( :operations, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9003 class GetOperationsResult < Struct.new( :operations, :next_page_token) SENSITIVE = [] include Aws::Structure end |