Class: Aws::Lightsail::Types::GetProfileResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#partnerTypes::PartnerInfo

An object that describes the partner membership of the account, such as the tier of the membership, its status, and when the account was enrolled.

This parameter is returned only for accounts that have a profileType of LightsailPartner.



9124
9125
9126
9127
9128
9129
# File 'lib/aws-sdk-lightsail/types.rb', line 9124

class GetProfileResult < Struct.new(
  :profile_type,
  :partner)
  SENSITIVE = []
  include Aws::Structure
end

#profile_typeString

The type of the profile.

The following profile types are possible:

  • Lightsailor – The account is not enrolled in the Lightsail partner program.

  • LightsailPartner – The account is enrolled in the Lightsail partner program.



9124
9125
9126
9127
9128
9129
# File 'lib/aws-sdk-lightsail/types.rb', line 9124

class GetProfileResult < Struct.new(
  :profile_type,
  :partner)
  SENSITIVE = []
  include Aws::Structure
end