Class: Aws::Lightsail::Types::GetRelationalDatabaseBlueprintsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetRelationalDatabaseBlueprintsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blueprints ⇒ Array<Types::RelationalDatabaseBlueprint>
An object describing the result of your get relational database blueprints request.
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#blueprints ⇒ Array<Types::RelationalDatabaseBlueprint>
An object describing the result of your get relational database blueprints request.
9079 9080 9081 9082 9083 9084 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9079 class GetRelationalDatabaseBlueprintsResult < Struct.new( :blueprints, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetRelationalDatabaseBlueprints request and specify the next page token using the pageToken parameter.
9079 9080 9081 9082 9083 9084 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9079 class GetRelationalDatabaseBlueprintsResult < Struct.new( :blueprints, :next_page_token) SENSITIVE = [] include Aws::Structure end |