Class: Aws::Lightsail::Types::GetRelationalDatabaseSnapshotsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetRelationalDatabaseSnapshotsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
-
#relational_database_snapshots ⇒ Array<Types::RelationalDatabaseSnapshot>
An object describing the result of your get relational database snapshots request.
Instance Attribute Details
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetRelationalDatabaseSnapshots request and specify the next page token using the pageToken parameter.
9645 9646 9647 9648 9649 9650 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9645 class GetRelationalDatabaseSnapshotsResult < Struct.new( :relational_database_snapshots, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#relational_database_snapshots ⇒ Array<Types::RelationalDatabaseSnapshot>
An object describing the result of your get relational database snapshots request.
9645 9646 9647 9648 9649 9650 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9645 class GetRelationalDatabaseSnapshotsResult < Struct.new( :relational_database_snapshots, :next_page_token) SENSITIVE = [] include Aws::Structure end |