Class: Aws::Lightsail::Types::GetStaticIpsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetStaticIpsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
-
#static_ips ⇒ Array<Types::StaticIp>
An array of key-value pairs containing information about your get static IPs request.
Instance Attribute Details
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetStaticIps
request and specify the next page token using the pageToken
parameter.
9921 9922 9923 9924 9925 9926 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9921 class GetStaticIpsResult < Struct.new( :static_ips, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#static_ips ⇒ Array<Types::StaticIp>
An array of key-value pairs containing information about your get static IPs request.
9921 9922 9923 9924 9925 9926 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9921 class GetStaticIpsResult < Struct.new( :static_ips, :next_page_token) SENSITIVE = [] include Aws::Structure end |