Class: Aws::Lightsail::Types::HostKeyAttributes

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Describes the public SSH host keys or the RDP certificate.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#algorithmString

The SSH host key algorithm or the RDP certificate format.

For SSH host keys, the algorithm may be ssh-rsa, ecdsa-sha2-nistp256, ssh-ed25519, etc. For RDP certificates, the algorithm is always x509-cert.



10026
10027
10028
10029
10030
10031
10032
10033
10034
10035
10036
# File 'lib/aws-sdk-lightsail/types.rb', line 10026

class HostKeyAttributes < Struct.new(
  :algorithm,
  :public_key,
  :witnessed_at,
  :fingerprint_sha1,
  :fingerprint_sha256,
  :not_valid_before,
  :not_valid_after)
  SENSITIVE = []
  include Aws::Structure
end

#fingerprint_sha1String

The SHA-1 fingerprint of the returned SSH host key or RDP certificate.

  • Example of an SHA-1 SSH fingerprint:

    SHA1:1CHH6FaAaXjtFOsR/t83vf91SR0

  • Example of an SHA-1 RDP fingerprint:

    af:34:51:fe:09:f0:e0:da:b8:4e:56:ca:60:c2:10:ff:38:06:db:45



10026
10027
10028
10029
10030
10031
10032
10033
10034
10035
10036
# File 'lib/aws-sdk-lightsail/types.rb', line 10026

class HostKeyAttributes < Struct.new(
  :algorithm,
  :public_key,
  :witnessed_at,
  :fingerprint_sha1,
  :fingerprint_sha256,
  :not_valid_before,
  :not_valid_after)
  SENSITIVE = []
  include Aws::Structure
end

#fingerprint_sha256String

The SHA-256 fingerprint of the returned SSH host key or RDP certificate.

  • Example of an SHA-256 SSH fingerprint:

    SHA256:KTsMnRBh1IhD17HpdfsbzeGA4jOijm5tyXsMjKVbB8o

  • Example of an SHA-256 RDP fingerprint:

    03:9b:36:9f:4b:de:4e:61:70:fc:7c:c9:78:e7:d2:1a:1c:25:a8:0c:91:f6:7c:e4:d6:a0:85:c8:b4:53:99:68



10026
10027
10028
10029
10030
10031
10032
10033
10034
10035
10036
# File 'lib/aws-sdk-lightsail/types.rb', line 10026

class HostKeyAttributes < Struct.new(
  :algorithm,
  :public_key,
  :witnessed_at,
  :fingerprint_sha1,
  :fingerprint_sha256,
  :not_valid_before,
  :not_valid_after)
  SENSITIVE = []
  include Aws::Structure
end

#not_valid_afterTime

The returned RDP certificate is not valid after this point in time.

This value is listed only for RDP certificates.



10026
10027
10028
10029
10030
10031
10032
10033
10034
10035
10036
# File 'lib/aws-sdk-lightsail/types.rb', line 10026

class HostKeyAttributes < Struct.new(
  :algorithm,
  :public_key,
  :witnessed_at,
  :fingerprint_sha1,
  :fingerprint_sha256,
  :not_valid_before,
  :not_valid_after)
  SENSITIVE = []
  include Aws::Structure
end

#not_valid_beforeTime

The returned RDP certificate is valid after this point in time.

This value is listed only for RDP certificates.



10026
10027
10028
10029
10030
10031
10032
10033
10034
10035
10036
# File 'lib/aws-sdk-lightsail/types.rb', line 10026

class HostKeyAttributes < Struct.new(
  :algorithm,
  :public_key,
  :witnessed_at,
  :fingerprint_sha1,
  :fingerprint_sha256,
  :not_valid_before,
  :not_valid_after)
  SENSITIVE = []
  include Aws::Structure
end

#public_keyString

The public SSH host key or the RDP certificate.



10026
10027
10028
10029
10030
10031
10032
10033
10034
10035
10036
# File 'lib/aws-sdk-lightsail/types.rb', line 10026

class HostKeyAttributes < Struct.new(
  :algorithm,
  :public_key,
  :witnessed_at,
  :fingerprint_sha1,
  :fingerprint_sha256,
  :not_valid_before,
  :not_valid_after)
  SENSITIVE = []
  include Aws::Structure
end

#witnessed_atTime

The time that the SSH host key or RDP certificate was recorded by Lightsail.



10026
10027
10028
10029
10030
10031
10032
10033
10034
10035
10036
# File 'lib/aws-sdk-lightsail/types.rb', line 10026

class HostKeyAttributes < Struct.new(
  :algorithm,
  :public_key,
  :witnessed_at,
  :fingerprint_sha1,
  :fingerprint_sha256,
  :not_valid_before,
  :not_valid_after)
  SENSITIVE = []
  include Aws::Structure
end