Class: Aws::Lightsail::Types::InputOrigin
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::InputOrigin
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes the origin resource of an Amazon Lightsail content delivery network (CDN) distribution.
An origin can be a Lightsail instance, bucket, container service, or load balancer. A distribution pulls content from an origin, caches it, and serves it to viewers via a worldwide network of edge servers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ip_address_type ⇒ String
The IP address type that the distribution uses when connecting to the origin.
-
#name ⇒ String
The name of the origin resource.
-
#protocol_policy ⇒ String
The protocol that your Amazon Lightsail distribution uses when establishing a connection with your origin to pull content.
-
#region_name ⇒ String
The AWS Region name of the origin resource.
-
#response_timeout ⇒ Integer
The amount of time, in seconds, that the distribution waits for a response after forwarding a request to the origin.
Instance Attribute Details
#ip_address_type ⇒ String
The IP address type that the distribution uses when connecting to the origin.
The possible values are ‘ipv4` for IPv4 only, `ipv6` for IPv6 only, and `dualstack` for IPv4 and IPv6.
9997 9998 9999 10000 10001 10002 10003 10004 10005 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9997 class InputOrigin < Struct.new( :name, :region_name, :protocol_policy, :response_timeout, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the origin resource.
9997 9998 9999 10000 10001 10002 10003 10004 10005 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9997 class InputOrigin < Struct.new( :name, :region_name, :protocol_policy, :response_timeout, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#protocol_policy ⇒ String
The protocol that your Amazon Lightsail distribution uses when establishing a connection with your origin to pull content.
9997 9998 9999 10000 10001 10002 10003 10004 10005 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9997 class InputOrigin < Struct.new( :name, :region_name, :protocol_policy, :response_timeout, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The AWS Region name of the origin resource.
9997 9998 9999 10000 10001 10002 10003 10004 10005 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9997 class InputOrigin < Struct.new( :name, :region_name, :protocol_policy, :response_timeout, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#response_timeout ⇒ Integer
The amount of time, in seconds, that the distribution waits for a response after forwarding a request to the origin. The minimum timeout is 1 second, the maximum is 60 seconds, and the default (if you don’t specify otherwise) is 30 seconds.
9997 9998 9999 10000 10001 10002 10003 10004 10005 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9997 class InputOrigin < Struct.new( :name, :region_name, :protocol_policy, :response_timeout, :ip_address_type) SENSITIVE = [] include Aws::Structure end |