Class: Aws::Lightsail::Types::InstanceMetadataOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::InstanceMetadataOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
The metadata options for the instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#http_endpoint ⇒ String
Indicates whether the HTTP metadata endpoint on your instances is enabled or disabled.
-
#http_protocol_ipv_6 ⇒ String
Indicates whether the IPv6 endpoint for the instance metadata service is enabled or disabled.
-
#http_put_response_hop_limit ⇒ Integer
The desired HTTP PUT response hop limit for instance metadata requests.
-
#http_tokens ⇒ String
The state of token usage for your instance metadata requests.
-
#state ⇒ String
The state of the metadata option changes.
Instance Attribute Details
#http_endpoint ⇒ String
Indicates whether the HTTP metadata endpoint on your instances is enabled or disabled.
If the value is disabled, you cannot access your instance metadata.
10463 10464 10465 10466 10467 10468 10469 10470 10471 |
# File 'lib/aws-sdk-lightsail/types.rb', line 10463 class InstanceMetadataOptions < Struct.new( :state, :http_tokens, :http_endpoint, :http_put_response_hop_limit, :http_protocol_ipv_6) SENSITIVE = [] include Aws::Structure end |
#http_protocol_ipv_6 ⇒ String
Indicates whether the IPv6 endpoint for the instance metadata service is enabled or disabled.
10463 10464 10465 10466 10467 10468 10469 10470 10471 |
# File 'lib/aws-sdk-lightsail/types.rb', line 10463 class InstanceMetadataOptions < Struct.new( :state, :http_tokens, :http_endpoint, :http_put_response_hop_limit, :http_protocol_ipv_6) SENSITIVE = [] include Aws::Structure end |
#http_put_response_hop_limit ⇒ Integer
The desired HTTP PUT response hop limit for instance metadata requests. A larger number means that the instance metadata requests can travel farther.
10463 10464 10465 10466 10467 10468 10469 10470 10471 |
# File 'lib/aws-sdk-lightsail/types.rb', line 10463 class InstanceMetadataOptions < Struct.new( :state, :http_tokens, :http_endpoint, :http_put_response_hop_limit, :http_protocol_ipv_6) SENSITIVE = [] include Aws::Structure end |
#http_tokens ⇒ String
The state of token usage for your instance metadata requests.
If the state is optional, you can choose whether to retrieve instance metadata with a signed token header on your request. If you retrieve the IAM role credentials without a token, the version 1.0 role credentials are returned. If you retrieve the IAM role credentials by using a valid signed token, the version 2.0 role credentials are returned.
If the state is required, you must send a signed token header with all instance metadata retrieval requests. In this state, retrieving the IAM role credential always returns the version 2.0 credentials. The version 1.0 credentials are not available.
Not all instance blueprints in Lightsail support version 2.0 credentials. Use the MetadataNoToken instance metric to track the number of calls to the instance metadata service that are using version 1.0 credentials. For more information, see [Viewing instance metrics in Amazon Lightsail][1] in the *Amazon Lightsail Developer Guide*.
[1]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-viewing-instance-health-metrics
10463 10464 10465 10466 10467 10468 10469 10470 10471 |
# File 'lib/aws-sdk-lightsail/types.rb', line 10463 class InstanceMetadataOptions < Struct.new( :state, :http_tokens, :http_endpoint, :http_put_response_hop_limit, :http_protocol_ipv_6) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the metadata option changes.
The following states are possible:
-
pending- The metadata options are being updated. The instance is not yet ready to process metadata traffic with the new selection. -
applied- The metadata options have been successfully applied to the instance.
10463 10464 10465 10466 10467 10468 10469 10470 10471 |
# File 'lib/aws-sdk-lightsail/types.rb', line 10463 class InstanceMetadataOptions < Struct.new( :state, :http_tokens, :http_endpoint, :http_put_response_hop_limit, :http_protocol_ipv_6) SENSITIVE = [] include Aws::Structure end |