Class: Aws::Lightsail::Types::InvalidInputException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Lightsail throws this exception when user input does not conform to the validation rules of an input field.

Domain and distribution APIs are only available in the N. Virginia (us-east-1) Amazon Web Services Region. Please set your Amazon Web Services Region configuration to us-east-1 to create, view, or edit these resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

Returns:

  • (String)


11137
11138
11139
11140
11141
11142
11143
11144
# File 'lib/aws-sdk-lightsail/types.rb', line 11137

class InvalidInputException < Struct.new(
  :code,
  :docs,
  :message,
  :tip)
  SENSITIVE = []
  include Aws::Structure
end

#docsString

Returns:

  • (String)


11137
11138
11139
11140
11141
11142
11143
11144
# File 'lib/aws-sdk-lightsail/types.rb', line 11137

class InvalidInputException < Struct.new(
  :code,
  :docs,
  :message,
  :tip)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

Returns:

  • (String)


11137
11138
11139
11140
11141
11142
11143
11144
# File 'lib/aws-sdk-lightsail/types.rb', line 11137

class InvalidInputException < Struct.new(
  :code,
  :docs,
  :message,
  :tip)
  SENSITIVE = []
  include Aws::Structure
end

#tipString

Returns:

  • (String)


11137
11138
11139
11140
11141
11142
11143
11144
# File 'lib/aws-sdk-lightsail/types.rb', line 11137

class InvalidInputException < Struct.new(
  :code,
  :docs,
  :message,
  :tip)
  SENSITIVE = []
  include Aws::Structure
end