Class: Aws::Lightsail::Types::KeyPair
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::KeyPair
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes an SSH key pair.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the key pair (
arn:aws:lightsail:us-east-2:123456789101:KeyPair/05859e3d-331d-48ba-9034-12345EXAMPLE). -
#created_at ⇒ Time
The timestamp when the key pair was created (
1479816991.349). -
#fingerprint ⇒ String
The RSA fingerprint of the key pair.
-
#location ⇒ Types::ResourceLocation
The region name and Availability Zone where the key pair was created.
-
#name ⇒ String
The friendly name of the SSH key pair.
-
#resource_type ⇒ String
The resource type (usually
KeyPair). -
#support_code ⇒ String
The support code.
-
#tags ⇒ Array<Types::Tag>
The tag keys and optional values for the resource.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the key pair (arn:aws:lightsail:us-east-2:123456789101:KeyPair/05859e3d-331d-48ba-9034-12345EXAMPLE).
11081 11082 11083 11084 11085 11086 11087 11088 11089 11090 11091 11092 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11081 class KeyPair < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :fingerprint) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the key pair was created (1479816991.349).
11081 11082 11083 11084 11085 11086 11087 11088 11089 11090 11091 11092 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11081 class KeyPair < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :fingerprint) SENSITIVE = [] include Aws::Structure end |
#fingerprint ⇒ String
The RSA fingerprint of the key pair.
11081 11082 11083 11084 11085 11086 11087 11088 11089 11090 11091 11092 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11081 class KeyPair < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :fingerprint) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::ResourceLocation
The region name and Availability Zone where the key pair was created.
11081 11082 11083 11084 11085 11086 11087 11088 11089 11090 11091 11092 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11081 class KeyPair < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :fingerprint) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The friendly name of the SSH key pair.
11081 11082 11083 11084 11085 11086 11087 11088 11089 11090 11091 11092 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11081 class KeyPair < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :fingerprint) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type (usually KeyPair).
11081 11082 11083 11084 11085 11086 11087 11088 11089 11090 11091 11092 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11081 class KeyPair < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :fingerprint) SENSITIVE = [] include Aws::Structure end |
#support_code ⇒ String
The support code. Include this code in your email to support when you have questions about an instance or another resource in Lightsail. This code enables our support team to look up your Lightsail information more easily.
11081 11082 11083 11084 11085 11086 11087 11088 11089 11090 11091 11092 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11081 class KeyPair < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :fingerprint) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tag keys and optional values for the resource. For more information about tags in Lightsail, see the [Amazon Lightsail Developer Guide][1].
[1]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-tags
11081 11082 11083 11084 11085 11086 11087 11088 11089 11090 11091 11092 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11081 class KeyPair < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :fingerprint) SENSITIVE = [] include Aws::Structure end |