Class: Aws::Lightsail::Types::LoadBalancerTlsCertificate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::LoadBalancerTlsCertificate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes a load balancer SSL/TLS certificate.
TLS is just an updated, more secure version of Secure Socket Layer (SSL).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the SSL/TLS certificate.
-
#created_at ⇒ Time
The time when you created your SSL/TLS certificate.
-
#domain_name ⇒ String
The domain name for your SSL/TLS certificate.
-
#domain_validation_records ⇒ Array<Types::LoadBalancerTlsCertificateDomainValidationRecord>
An array of LoadBalancerTlsCertificateDomainValidationRecord objects describing the records.
-
#failure_reason ⇒ String
The validation failure reason, if any, of the certificate.
-
#is_attached ⇒ Boolean
When ‘true`, the SSL/TLS certificate is attached to the Lightsail load balancer.
-
#issued_at ⇒ Time
The time when the SSL/TLS certificate was issued.
-
#issuer ⇒ String
The issuer of the certificate.
-
#key_algorithm ⇒ String
The algorithm used to generate the key pair (the public and private key).
-
#load_balancer_name ⇒ String
The load balancer name where your SSL/TLS certificate is attached.
-
#location ⇒ Types::ResourceLocation
The Amazon Web Services Region and Availability Zone where you created your certificate.
-
#name ⇒ String
The name of the SSL/TLS certificate (‘my-certificate`).
-
#not_after ⇒ Time
The timestamp when the SSL/TLS certificate expires.
-
#not_before ⇒ Time
The timestamp when the SSL/TLS certificate is first valid.
-
#renewal_summary ⇒ Types::LoadBalancerTlsCertificateRenewalSummary
An object that describes the status of the certificate renewal managed by Lightsail.
-
#resource_type ⇒ String
The resource type (‘LoadBalancerTlsCertificate`).
-
#revocation_reason ⇒ String
The reason the certificate was revoked.
-
#revoked_at ⇒ Time
The timestamp when the certificate was revoked.
-
#serial ⇒ String
The serial number of the certificate.
-
#signature_algorithm ⇒ String
The algorithm that was used to sign the certificate.
-
#status ⇒ String
The validation status of the SSL/TLS certificate.
-
#subject ⇒ String
The name of the entity that is associated with the public key contained in the certificate.
-
#subject_alternative_names ⇒ Array<String>
An array of strings that specify the alternate domains (‘example2.com`) and subdomains (`blog.example.com`) for the certificate.
-
#support_code ⇒ String
The support code.
-
#tags ⇒ Array<Types::Tag>
The tag keys and optional values for the resource.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the SSL/TLS certificate.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time when you created your SSL/TLS certificate.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name for your SSL/TLS certificate.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#domain_validation_records ⇒ Array<Types::LoadBalancerTlsCertificateDomainValidationRecord>
An array of LoadBalancerTlsCertificateDomainValidationRecord objects describing the records.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The validation failure reason, if any, of the certificate.
The following failure reasons are possible:
-
NO_AVAILABLE_CONTACTS- This failure applies to email validation, which is not available for Lightsail certificates. -
ADDITIONAL_VERIFICATION_REQUIRED- Lightsail requires additional information to process this certificate request. This can happen as a fraud-protection measure, such as when the domain ranks within the Alexa top 1000 websites. To provide the required information, use the [AWS Support Center] to contact AWS Support.<note markdown=“1”> You cannot request a certificate for Amazon-owned domain names such as those ending in amazonaws.com, cloudfront.net, or elasticbeanstalk.com.
</note> -
DOMAIN_NOT_ALLOWED- One or more of the domain names in the certificate request was reported as an unsafe domain by [VirusTotal]. To correct the problem, search for your domain name on the [VirusTotal] website. If your domain is reported as suspicious, see [Google Help for Hacked Websites] to learn what you can do.If you believe that the result is a false positive, notify the organization that is reporting the domain. VirusTotal is an aggregate of several antivirus and URL scanners and cannot remove your domain from a block list itself. After you correct the problem and the VirusTotal registry has been updated, request a new certificate.
If you see this error and your domain is not included in the VirusTotal list, visit the [AWS Support Center] and create a case.
-
INVALID_PUBLIC_DOMAIN- One or more of the domain names in the certificate request is not valid. Typically, this is because a domain name in the request is not a valid top-level domain. Try to request a certificate again, correcting any spelling errors or typos that were in the failed request, and ensure that all domain names in the request are for valid top-level domains. For example, you cannot request a certificate for ‘example.invalidpublicdomain` because `invalidpublicdomain` is not a valid top-level domain. -
OTHER- Typically, this failure occurs when there is a typographical error in one or more of the domain names in the certificate request. Try to request a certificate again, correcting any spelling errors or typos that were in the failed request.
[1]: console.aws.amazon.com/support/home [2]: www.virustotal.com/gui/home/url [3]: developers.google.com/web/fundamentals/security/hacked
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#is_attached ⇒ Boolean
When ‘true`, the SSL/TLS certificate is attached to the Lightsail load balancer.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#issued_at ⇒ Time
The time when the SSL/TLS certificate was issued.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#issuer ⇒ String
The issuer of the certificate.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#key_algorithm ⇒ String
The algorithm used to generate the key pair (the public and private key).
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#load_balancer_name ⇒ String
The load balancer name where your SSL/TLS certificate is attached.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::ResourceLocation
The Amazon Web Services Region and Availability Zone where you created your certificate.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the SSL/TLS certificate (‘my-certificate`).
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#not_after ⇒ Time
The timestamp when the SSL/TLS certificate expires.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#not_before ⇒ Time
The timestamp when the SSL/TLS certificate is first valid.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#renewal_summary ⇒ Types::LoadBalancerTlsCertificateRenewalSummary
An object that describes the status of the certificate renewal managed by Lightsail.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type (‘LoadBalancerTlsCertificate`).
-
Instance- A Lightsail instance (a virtual private server) -
StaticIp- A static IP address -
KeyPair- The key pair used to connect to a Lightsail instance -
InstanceSnapshot- A Lightsail instance snapshot -
Domain- A DNS zone -
PeeredVpc- A peered VPC -
LoadBalancer- A Lightsail load balancer -
LoadBalancerTlsCertificate- An SSL/TLS certificate associated with a Lightsail load balancer -
Disk- A Lightsail block storage disk -
DiskSnapshot- A block storage disk snapshot
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#revocation_reason ⇒ String
The reason the certificate was revoked. This value is present only when the certificate status is ‘REVOKED`.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#revoked_at ⇒ Time
The timestamp when the certificate was revoked. This value is present only when the certificate status is ‘REVOKED`.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#serial ⇒ String
The serial number of the certificate.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#signature_algorithm ⇒ String
The algorithm that was used to sign the certificate.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The validation status of the SSL/TLS certificate. Valid values are below.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#subject ⇒ String
The name of the entity that is associated with the public key contained in the certificate.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#subject_alternative_names ⇒ Array<String>
An array of strings that specify the alternate domains (‘example2.com`) and subdomains (`blog.example.com`) for the certificate.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#support_code ⇒ String
The support code. Include this code in your email to support when you have questions about your Lightsail load balancer or SSL/TLS certificate. This code enables our support team to look up your Lightsail information more easily.
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tag keys and optional values for the resource. For more information about tags in Lightsail, see the [Amazon Lightsail Developer Guide].
[1]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-tags
11603 11604 11605 11606 11607 11608 11609 11610 11611 11612 11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-lightsail/types.rb', line 11603 class LoadBalancerTlsCertificate < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :tags, :load_balancer_name, :is_attached, :status, :domain_name, :domain_validation_records, :failure_reason, :issued_at, :issuer, :key_algorithm, :not_after, :not_before, :renewal_summary, :revocation_reason, :revoked_at, :serial, :signature_algorithm, :subject, :subject_alternative_names) SENSITIVE = [] include Aws::Structure end |