Class: Aws::Lightsail::Types::MonitoredResourceInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::MonitoredResourceInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes resource being monitored by an alarm.
An alarm is a way to monitor your Amazon Lightsail resource metrics. For more information, see Alarms in Amazon Lightsail.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource being monitored.
-
#name ⇒ String
The name of the Lightsail resource being monitored.
-
#resource_type ⇒ String
The Lightsail resource type of the resource being monitored.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource being monitored.
12074 12075 12076 12077 12078 12079 12080 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12074 class MonitoredResourceInfo < Struct.new( :arn, :name, :resource_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Lightsail resource being monitored.
12074 12075 12076 12077 12078 12079 12080 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12074 class MonitoredResourceInfo < Struct.new( :arn, :name, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The Lightsail resource type of the resource being monitored.
Instances, load balancers, and relational databases are the only Lightsail resources that can currently be monitored by alarms.
12074 12075 12076 12077 12078 12079 12080 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12074 class MonitoredResourceInfo < Struct.new( :arn, :name, :resource_type) SENSITIVE = [] include Aws::Structure end |