Class: Aws::Lightsail::Types::Origin

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Describes the origin resource of an Amazon Lightsail content delivery network (CDN) distribution.

An origin can be a Lightsail instance, bucket, or load balancer. A distribution pulls content from an origin, caches it, and serves it to viewers via a worldwide network of edge servers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ip_address_typeString

The IP address type that the distribution uses when connecting to the origin.

The possible values are ipv4 for IPv4 only, ipv6 for IPv6 only, and dualstack for IPv4 and IPv6.

Returns:

  • (String)


12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
# File 'lib/aws-sdk-lightsail/types.rb', line 12336

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type,
  :is_private_origin_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#is_private_origin_access_enabledBoolean

Specifies whether private origin access is enabled for the distribution's origin. With private origin access, the distribution can serve objects that aren't publicly accessible from a Lightsail bucket.

This applies when you set the bucket's getObject access rule to private. It also applies when you set getObject to public but set individual objects to private.

Returns:

  • (Boolean)


12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
# File 'lib/aws-sdk-lightsail/types.rb', line 12336

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type,
  :is_private_origin_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the origin resource.

Returns:

  • (String)


12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
# File 'lib/aws-sdk-lightsail/types.rb', line 12336

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type,
  :is_private_origin_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#protocol_policyString

The protocol that your Amazon Lightsail distribution uses when establishing a connection with your origin to pull content.

Returns:

  • (String)


12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
# File 'lib/aws-sdk-lightsail/types.rb', line 12336

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type,
  :is_private_origin_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#region_nameString

The AWS Region name of the origin resource.

Returns:

  • (String)


12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
# File 'lib/aws-sdk-lightsail/types.rb', line 12336

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type,
  :is_private_origin_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type of the origin resource (Instance).

Returns:

  • (String)


12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
# File 'lib/aws-sdk-lightsail/types.rb', line 12336

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type,
  :is_private_origin_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#response_timeoutInteger

The amount of time, in seconds, that the distribution waits for a response after forwarding a request to the origin. The minimum timeout is 1 second, the maximum is 60 seconds, and the default (if you don't specify otherwise) is 30 seconds.

Returns:

  • (Integer)


12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
# File 'lib/aws-sdk-lightsail/types.rb', line 12336

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type,
  :is_private_origin_access_enabled)
  SENSITIVE = []
  include Aws::Structure
end