Class: Aws::Lightsail::Types::PeerVpcResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operationTypes::Operation

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.



12438
12439
12440
12441
12442
# File 'lib/aws-sdk-lightsail/types.rb', line 12438

class PeerVpcResult < Struct.new(
  :operation)
  SENSITIVE = []
  include Aws::Structure
end