Class: Aws::Lightsail::Types::PutAlarmResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::PutAlarmResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
12720 12721 12722 12723 12724 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12720 class PutAlarmResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |