Class: Aws::Lightsail::Types::PutInstancePublicPortsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::PutInstancePublicPortsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
12921 12922 12923 12924 12925 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12921 class PutInstancePublicPortsResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |