Class: Aws::Lightsail::Types::QueryStringObject
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::QueryStringObject
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes the query string parameters that an Amazon Lightsail content delivery network (CDN) distribution to bases caching on.
For the query strings that you specify, your distribution caches separate versions of the specified content based on the query string values in viewer requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#option ⇒ Boolean
Indicates whether the distribution forwards and caches based on query strings.
-
#query_strings_allow_list ⇒ Array<String>
The specific query strings that the distribution forwards to the origin.
Instance Attribute Details
#option ⇒ Boolean
Indicates whether the distribution forwards and caches based on query strings.
12748 12749 12750 12751 12752 12753 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12748 class QueryStringObject < Struct.new( :option, :query_strings_allow_list) SENSITIVE = [] include Aws::Structure end |
#query_strings_allow_list ⇒ Array<String>
The specific query strings that the distribution forwards to the origin.
Your distribution will cache content based on the specified query strings.
If the option parameter is true, then your distribution forwards all query strings, regardless of what you specify using the queryStringsAllowList parameter.
12748 12749 12750 12751 12752 12753 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12748 class QueryStringObject < Struct.new( :option, :query_strings_allow_list) SENSITIVE = [] include Aws::Structure end |