Class: Aws::Lightsail::Types::RebootInstanceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::RebootInstanceResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
13011 13012 13013 13014 13015 |
# File 'lib/aws-sdk-lightsail/types.rb', line 13011 class RebootInstanceResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |