Class: Aws::Lightsail::Types::RebootRelationalDatabaseResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::RebootRelationalDatabaseResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
13037 13038 13039 13040 13041 |
# File 'lib/aws-sdk-lightsail/types.rb', line 13037 class RebootRelationalDatabaseResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |