Class: Aws::Lightsail::Types::ReleaseStaticIpResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::ReleaseStaticIpResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
13742 13743 13744 13745 13746 |
# File 'lib/aws-sdk-lightsail/types.rb', line 13742 class ReleaseStaticIpResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |