Class: Aws::Lightsail::Types::ResetDistributionCacheResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_timeTime

The timestamp of the reset cache request (1479734909.17) in Unix time format.

Returns:



13833
13834
13835
13836
13837
13838
13839
# File 'lib/aws-sdk-lightsail/types.rb', line 13833

class ResetDistributionCacheResult < Struct.new(
  :status,
  :create_time,
  :operation)
  SENSITIVE = []
  include Aws::Structure
end

#operationTypes::Operation

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.

Returns:



13833
13834
13835
13836
13837
13838
13839
# File 'lib/aws-sdk-lightsail/types.rb', line 13833

class ResetDistributionCacheResult < Struct.new(
  :status,
  :create_time,
  :operation)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the reset cache request.

Returns:



13833
13834
13835
13836
13837
13838
13839
# File 'lib/aws-sdk-lightsail/types.rb', line 13833

class ResetDistributionCacheResult < Struct.new(
  :status,
  :create_time,
  :operation)
  SENSITIVE = []
  include Aws::Structure
end