Class: Aws::Lightsail::Types::SendContactMethodVerificationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::SendContactMethodVerificationResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
13755 13756 13757 13758 13759 |
# File 'lib/aws-sdk-lightsail/types.rb', line 13755 class SendContactMethodVerificationResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |