Class: Aws::Lightsail::Types::Session

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Describes a web-based, remote graphical user interface (GUI), Amazon DCV session. The session is used to access a virtual computer’s operating system or application.

Constant Summary collapse

SENSITIVE =
[:url]

Instance Attribute Summary collapse

Instance Attribute Details

#is_primaryBoolean

When true, this Boolean value indicates the primary session for the specified resource.



14010
14011
14012
14013
14014
14015
14016
# File 'lib/aws-sdk-lightsail/types.rb', line 14010

class Session < Struct.new(
  :name,
  :url,
  :is_primary)
  SENSITIVE = [:url]
  include Aws::Structure
end

#nameString

The session name.



14010
14011
14012
14013
14014
14015
14016
# File 'lib/aws-sdk-lightsail/types.rb', line 14010

class Session < Struct.new(
  :name,
  :url,
  :is_primary)
  SENSITIVE = [:url]
  include Aws::Structure
end

#urlString

The session URL.



14010
14011
14012
14013
14014
14015
14016
# File 'lib/aws-sdk-lightsail/types.rb', line 14010

class Session < Struct.new(
  :name,
  :url,
  :is_primary)
  SENSITIVE = [:url]
  include Aws::Structure
end