Class: Aws::Lightsail::Types::SetIpAddressTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::SetIpAddressTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accept_bundle_update ⇒ Boolean
Required parameter to accept the instance bundle update when changing to, and from, IPv6-only.
-
#ip_address_type ⇒ String
The IP address type to set for the specified resource.
-
#resource_name ⇒ String
The name of the resource for which to set the IP address type.
-
#resource_type ⇒ String
The resource type.
Instance Attribute Details
#accept_bundle_update ⇒ Boolean
Required parameter to accept the instance bundle update when changing to, and from, IPv6-only.
dual-stack or
ipv4, to ipv6. It also changes when switching from ipv6, to
dual-stack or ipv4.
You must include this parameter in the command to update the bundle.
For example, if you switch from dual-stack to ipv6, the bundle
will be updated, and billing for the IPv6-only instance bundle
begins immediately.
14061 14062 14063 14064 14065 14066 14067 14068 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14061 class SetIpAddressTypeRequest < Struct.new( :resource_type, :resource_name, :ip_address_type, :accept_bundle_update) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type to set for the specified resource.
The possible values are ipv4 for IPv4 only, ipv6 for IPv6 only,
and dualstack for IPv4 and IPv6.
14061 14062 14063 14064 14065 14066 14067 14068 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14061 class SetIpAddressTypeRequest < Struct.new( :resource_type, :resource_name, :ip_address_type, :accept_bundle_update) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
The name of the resource for which to set the IP address type.
14061 14062 14063 14064 14065 14066 14067 14068 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14061 class SetIpAddressTypeRequest < Struct.new( :resource_type, :resource_name, :ip_address_type, :accept_bundle_update) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type.
The resource values are Distribution, Instance, and
LoadBalancer.
us-east-1) Amazon Web Services Region. Set your Amazon Web
Services Region configuration to us-east-1 to create, view, or
edit distributions.
14061 14062 14063 14064 14065 14066 14067 14068 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14061 class SetIpAddressTypeRequest < Struct.new( :resource_type, :resource_name, :ip_address_type, :accept_bundle_update) SENSITIVE = [] include Aws::Structure end |