Class: Aws::Lightsail::Types::SetIpAddressTypeResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::SetIpAddressTypeResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
13873 13874 13875 13876 13877 |
# File 'lib/aws-sdk-lightsail/types.rb', line 13873 class SetIpAddressTypeResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |