Class: Aws::Lightsail::Types::StartInstanceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::StartInstanceResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14185 14186 14187 14188 14189 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14185 class StartInstanceResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |