Class: Aws::Lightsail::Types::StartRelationalDatabaseResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::StartRelationalDatabaseResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14380 14381 14382 14383 14384 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14380 class StartRelationalDatabaseResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |