Class: Aws::Lightsail::Types::StopInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::StopInstanceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#force ⇒ Boolean
When set to
True, forces a Lightsail instance that is stuck in astoppingstate to stop. -
#instance_name ⇒ String
The name of the instance (a virtual private server) to stop.
Instance Attribute Details
#force ⇒ Boolean
When set to True, forces a Lightsail instance that is stuck in a stopping state to stop.
Only use the force parameter if your instance is stuck in the stopping state. In any other state, your instance should stop normally without adding this parameter to your API request.
14301 14302 14303 14304 14305 14306 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14301 class StopInstanceRequest < Struct.new( :instance_name, :force) SENSITIVE = [] include Aws::Structure end |
#instance_name ⇒ String
The name of the instance (a virtual private server) to stop.
14301 14302 14303 14304 14305 14306 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14301 class StopInstanceRequest < Struct.new( :instance_name, :force) SENSITIVE = [] include Aws::Structure end |