Class: Aws::Lightsail::Types::StopInstanceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::StopInstanceResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14521 14522 14523 14524 14525 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14521 class StopInstanceResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |