Class: Aws::Lightsail::Types::TagResourceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::TagResourceResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14399 14400 14401 14402 14403 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14399 class TagResourceResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |