Class: Aws::Lightsail::Types::TestAlarmRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_nameString

The name of the alarm to test.

Returns:

  • (String)


14444
14445
14446
14447
14448
14449
# File 'lib/aws-sdk-lightsail/types.rb', line 14444

class TestAlarmRequest < Struct.new(
  :alarm_name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The alarm state to test.

An alarm has the following possible states that can be tested:

  • ALARM - The metric is outside of the defined threshold.

  • INSUFFICIENT_DATA - The alarm has just started, the metric is not available, or not enough data is available for the metric to determine the alarm state.

  • OK - The metric is within the defined threshold.

Returns:

  • (String)


14444
14445
14446
14447
14448
14449
# File 'lib/aws-sdk-lightsail/types.rb', line 14444

class TestAlarmRequest < Struct.new(
  :alarm_name,
  :state)
  SENSITIVE = []
  include Aws::Structure
end