Class: Aws::Lightsail::Types::TestAlarmResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::TestAlarmResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14495 14496 14497 14498 14499 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14495 class TestAlarmResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |