Class: Aws::Lightsail::Types::UnpeerVpcResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UnpeerVpcResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14571 14572 14573 14574 14575 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14571 class UnpeerVpcResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |