Class: Aws::Lightsail::Types::UpdateBucketBundleResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateBucketBundleResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14610 14611 14612 14613 14614 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14610 class UpdateBucketBundleResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |