Class: Aws::Lightsail::Types::UpdateBucketResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateBucketResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ Types::Bucket
An object that describes the bucket that is updated.
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#bucket ⇒ Types::Bucket
An object that describes the bucket that is updated.
14897 14898 14899 14900 14901 14902 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14897 class UpdateBucketResult < Struct.new( :bucket, :operations) SENSITIVE = [] include Aws::Structure end |
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14897 14898 14899 14900 14901 14902 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14897 class UpdateBucketResult < Struct.new( :bucket, :operations) SENSITIVE = [] include Aws::Structure end |