Class: Aws::Lightsail::Types::UpdateContainerServiceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateContainerServiceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_disabled ⇒ Boolean
A Boolean value to indicate whether the container service is disabled.
-
#power ⇒ String
The power for the container service.
-
#private_registry_access ⇒ Types::PrivateRegistryAccessRequest
An object to describe the configuration for the container service to access private container image repositories, such as Amazon Elastic Container Registry (Amazon ECR) private repositories.
-
#public_domain_names ⇒ Hash<String,Array<String>>
The public domain names to use with the container service, such as
example.comandwww.example.com. -
#scale ⇒ Integer
The scale for the container service.
-
#service_name ⇒ String
The name of the container service to update.
Instance Attribute Details
#is_disabled ⇒ Boolean
A Boolean value to indicate whether the container service is disabled.
14769 14770 14771 14772 14773 14774 14775 14776 14777 14778 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14769 class UpdateContainerServiceRequest < Struct.new( :service_name, :power, :scale, :is_disabled, :public_domain_names, :private_registry_access) SENSITIVE = [] include Aws::Structure end |
#power ⇒ String
The power for the container service.
The power specifies the amount of memory, vCPUs, and base monthly cost of each node of the container service. The power and scale of a container service makes up its configured capacity. To determine the monthly price of your container service, multiply the base price of the power with the scale (the number of nodes) of the service.
Use the GetContainerServicePowers action to view the specifications of each power option.
14769 14770 14771 14772 14773 14774 14775 14776 14777 14778 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14769 class UpdateContainerServiceRequest < Struct.new( :service_name, :power, :scale, :is_disabled, :public_domain_names, :private_registry_access) SENSITIVE = [] include Aws::Structure end |
#private_registry_access ⇒ Types::PrivateRegistryAccessRequest
An object to describe the configuration for the container service to access private container image repositories, such as Amazon Elastic Container Registry (Amazon ECR) private repositories.
For more information, see [Configuring access to an Amazon ECR private repository for an Amazon Lightsail container service][1] in the *Amazon Lightsail Developer Guide*.
14769 14770 14771 14772 14773 14774 14775 14776 14777 14778 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14769 class UpdateContainerServiceRequest < Struct.new( :service_name, :power, :scale, :is_disabled, :public_domain_names, :private_registry_access) SENSITIVE = [] include Aws::Structure end |
#public_domain_names ⇒ Hash<String,Array<String>>
The public domain names to use with the container service, such as example.com and www.example.com.
You can specify up to four public domain names for a container service. The domain names that you specify are used when you create a deployment with a container configured as the public endpoint of your container service.
If you don’t specify public domain names, then you can use the default domain of the container service.
You must create and validate an SSL/TLS certificate before you can use public domain names with your container service. Use the CreateCertificate action to create a certificate for the public domain names you want to use with your container service.
You can specify public domain names using a string to array map as shown in the example later on this page.
14769 14770 14771 14772 14773 14774 14775 14776 14777 14778 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14769 class UpdateContainerServiceRequest < Struct.new( :service_name, :power, :scale, :is_disabled, :public_domain_names, :private_registry_access) SENSITIVE = [] include Aws::Structure end |
#scale ⇒ Integer
The scale for the container service.
The scale specifies the allocated compute nodes of the container service. The power and scale of a container service makes up its configured capacity. To determine the monthly price of your container service, multiply the base price of the power with the scale (the number of nodes) of the service.
14769 14770 14771 14772 14773 14774 14775 14776 14777 14778 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14769 class UpdateContainerServiceRequest < Struct.new( :service_name, :power, :scale, :is_disabled, :public_domain_names, :private_registry_access) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the container service to update.
14769 14770 14771 14772 14773 14774 14775 14776 14777 14778 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14769 class UpdateContainerServiceRequest < Struct.new( :service_name, :power, :scale, :is_disabled, :public_domain_names, :private_registry_access) SENSITIVE = [] include Aws::Structure end |