Class: Aws::Lightsail::Types::UpdateDistributionBundleResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateDistributionBundleResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An object that describes the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An object that describes the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14823 14824 14825 14826 14827 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14823 class UpdateDistributionBundleResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |