Class: Aws::Lightsail::Types::UpdateDistributionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateDistributionResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
15165 15166 15167 15168 15169 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15165 class UpdateDistributionResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |