Class: Aws::Lightsail::Types::UpdateDomainEntryResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateDomainEntryResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
15197 15198 15199 15200 15201 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15197 class UpdateDomainEntryResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |