Class: Aws::Lightsail::Types::UpdateInstanceMetadataOptionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateInstanceMetadataOptionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
15271 15272 15273 15274 15275 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15271 class UpdateInstanceMetadataOptionsResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |