Class: Aws::Lightsail::Types::UpdateLoadBalancerAttributeResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateLoadBalancerAttributeResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
15342 15343 15344 15345 15346 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15342 class UpdateLoadBalancerAttributeResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |