Class: Aws::Lightsail::Types::UpdateRelationalDatabaseParametersResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateRelationalDatabaseParametersResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
15373 15374 15375 15376 15377 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15373 class UpdateRelationalDatabaseParametersResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |