Class: Aws::Lightsail::Types::ContainerServiceHealthCheckConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::ContainerServiceHealthCheckConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes the health check configuration of an Amazon Lightsail container service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#healthy_threshold ⇒ Integer
The number of consecutive health checks successes required before moving the container to the
Healthystate. -
#interval_seconds ⇒ Integer
The approximate interval, in seconds, between health checks of an individual container.
-
#path ⇒ String
The path on the container on which to perform the health check.
-
#success_codes ⇒ String
The HTTP codes to use when checking for a successful response from a container.
-
#timeout_seconds ⇒ Integer
The amount of time, in seconds, during which no response means a failed health check.
-
#unhealthy_threshold ⇒ Integer
The number of consecutive health check failures required before moving the container to the
Unhealthystate.
Instance Attribute Details
#healthy_threshold ⇒ Integer
The number of consecutive health checks successes required before moving the container to the Healthy state. The default value is 2.
2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2629 class ContainerServiceHealthCheckConfig < Struct.new( :healthy_threshold, :unhealthy_threshold, :timeout_seconds, :interval_seconds, :path, :success_codes) SENSITIVE = [] include Aws::Structure end |
#interval_seconds ⇒ Integer
The approximate interval, in seconds, between health checks of an individual container. You can specify between 5 and 300 seconds. The default value is 5.
2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2629 class ContainerServiceHealthCheckConfig < Struct.new( :healthy_threshold, :unhealthy_threshold, :timeout_seconds, :interval_seconds, :path, :success_codes) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path on the container on which to perform the health check. The default value is /.
2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2629 class ContainerServiceHealthCheckConfig < Struct.new( :healthy_threshold, :unhealthy_threshold, :timeout_seconds, :interval_seconds, :path, :success_codes) SENSITIVE = [] include Aws::Structure end |
#success_codes ⇒ String
The HTTP codes to use when checking for a successful response from a container. You can specify values between 200 and 499. You can specify multiple values (for example, ‘200,202`) or a range of values (for example, 200-299).
2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2629 class ContainerServiceHealthCheckConfig < Struct.new( :healthy_threshold, :unhealthy_threshold, :timeout_seconds, :interval_seconds, :path, :success_codes) SENSITIVE = [] include Aws::Structure end |
#timeout_seconds ⇒ Integer
The amount of time, in seconds, during which no response means a failed health check. You can specify between 2 and 60 seconds. The default value is 2.
2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2629 class ContainerServiceHealthCheckConfig < Struct.new( :healthy_threshold, :unhealthy_threshold, :timeout_seconds, :interval_seconds, :path, :success_codes) SENSITIVE = [] include Aws::Structure end |
#unhealthy_threshold ⇒ Integer
The number of consecutive health check failures required before moving the container to the Unhealthy state. The default value is 2.
2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2629 class ContainerServiceHealthCheckConfig < Struct.new( :healthy_threshold, :unhealthy_threshold, :timeout_seconds, :interval_seconds, :path, :success_codes) SENSITIVE = [] include Aws::Structure end |