Class: Aws::Lightsail::Types::ContainerServiceStateDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::ContainerServiceStateDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes the current state of a container service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The state code of the container service.
-
#message ⇒ String
A message that provides more information for the state code.
Instance Attribute Details
#code ⇒ String
The state code of the container service.
The following state codes are possible:
-
The following state codes are possible if your container service is in a
DEPLOYINGorUPDATINGstate: -
CREATING_SYSTEM_RESOURCES- The system resources for your container service are being created. -
CREATING_NETWORK_INFRASTRUCTURE- The network infrastructure for your container service are being created. -
PROVISIONING_CERTIFICATE- The SSL/TLS certificate for your container service is being created. -
PROVISIONING_SERVICE- Your container service is being provisioned. -
CREATING_DEPLOYMENT- Your deployment is being created on your container service. -
EVALUATING_HEALTH_CHECK- The health of your deployment is being evaluated. -
ACTIVATING_DEPLOYMENT- Your deployment is being activated. -
The following state codes are possible if your container service is in a
PENDINGstate: -
CERTIFICATE_LIMIT_EXCEEDED- The SSL/TLS certificate required for your container service exceeds the maximum number of certificates allowed for your account. -
UNKNOWN_ERROR- An error was experienced when your container service was being created.
2804 2805 2806 2807 2808 2809 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2804 class ContainerServiceStateDetail < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message that provides more information for the state code.
PENDING, DEPLOYING, or UPDATING state.
2804 2805 2806 2807 2808 2809 |
# File 'lib/aws-sdk-lightsail/types.rb', line 2804 class ContainerServiceStateDetail < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |