Class: Aws::Lightsail::Types::CreateBucketResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketTypes::Bucket

An object that describes the bucket that is created.



3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-lightsail/types.rb', line 3063

class CreateBucketResult < Struct.new(
  :bucket,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end

#operationsArray<Types::Operation>

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.



3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-lightsail/types.rb', line 3063

class CreateBucketResult < Struct.new(
  :bucket,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end