Class: Aws::Lightsail::Types::CreateDistributionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateDistributionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bundle_id ⇒ String
The bundle ID to use for the distribution.
-
#cache_behavior_settings ⇒ Types::CacheSettings
An object that describes the cache behavior settings for the distribution.
-
#cache_behaviors ⇒ Array<Types::CacheBehaviorPerPath>
An array of objects that describe the per-path cache behavior for the distribution.
-
#certificate_name ⇒ String
The name of the SSL/TLS certificate that you want to attach to the distribution.
-
#custom_error_responses ⇒ Array<Types::DistributionCustomErrorResponse>
An array of objects that describe the custom error responses for the distribution.
-
#default_cache_behavior ⇒ Types::CacheBehavior
An object that describes the default cache behavior for the distribution.
-
#default_root_object ⇒ String
The object (for example,
index.html) that the distribution returns when a viewer requests the root URL of the distribution (/) instead of a specific object. -
#distribution_name ⇒ String
The name for the distribution.
-
#enable_private_origin_access ⇒ Boolean
Specifies whether to enable private origin access for the distribution.
-
#ip_address_type ⇒ String
The IP address type for the distribution.
-
#origin ⇒ Types::InputOrigin
An object that describes the origin resource for the distribution, such as a Lightsail instance, bucket, or load balancer.
-
#tags ⇒ Array<Types::Tag>
The tag keys and optional values to add to the distribution during create.
-
#viewer_minimum_tls_protocol_version ⇒ String
The minimum TLS protocol version for the SSL/TLS certificate.
Instance Attribute Details
#bundle_id ⇒ String
The bundle ID to use for the distribution.
A distribution bundle describes the specifications of your distribution, such as the monthly cost and monthly network transfer quota.
Use the GetDistributionBundles action to get a list of
distribution bundle IDs that you can specify.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#cache_behavior_settings ⇒ Types::CacheSettings
An object that describes the cache behavior settings for the distribution.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#cache_behaviors ⇒ Array<Types::CacheBehaviorPerPath>
An array of objects that describe the per-path cache behavior for the distribution.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#certificate_name ⇒ String
The name of the SSL/TLS certificate that you want to attach to the distribution.
Use the GetCertificates action to get a list of certificate names that you can specify.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#custom_error_responses ⇒ Array<Types::DistributionCustomErrorResponse>
An array of objects that describe the custom error responses for the distribution. With a custom error response, you can specify the page to return when the origin responds with a given HTTP error code. You can also specify the HTTP status code to send to the viewer.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#default_cache_behavior ⇒ Types::CacheBehavior
An object that describes the default cache behavior for the distribution.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#default_root_object ⇒ String
The object (for example, index.html) that the distribution returns
when a viewer requests the root URL of the distribution (/)
instead of a specific object. The object that you specify must be
available from the origin.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#distribution_name ⇒ String
The name for the distribution.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#enable_private_origin_access ⇒ Boolean
Specifies whether to enable private origin access for the distribution. With private origin access, the distribution can serve objects that aren't publicly accessible from a Lightsail bucket.
Lightsail grants the distribution permission to read the bucket's objects. Enabling private origin access doesn't change the bucket's access settings, and you can still retrieve publicly accessible objects directly from the bucket's endpoint.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type for the distribution.
The possible values are ipv4 for IPv4 only, and dualstack for
IPv4 and IPv6.
The default value is dualstack.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ Types::InputOrigin
An object that describes the origin resource for the distribution, such as a Lightsail instance, bucket, or load balancer.
The distribution pulls, caches, and serves content from the origin.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tag keys and optional values to add to the distribution during create.
Use the TagResource action to tag a resource after it's created.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#viewer_minimum_tls_protocol_version ⇒ String
The minimum TLS protocol version for the SSL/TLS certificate.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3800 class CreateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :bundle_id, :ip_address_type, :tags, :certificate_name, :viewer_minimum_tls_protocol_version, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |