Class: Aws::Lightsail::Types::CreateDomainResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateDomainResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
3898 3899 3900 3901 3902 |
# File 'lib/aws-sdk-lightsail/types.rb', line 3898 class CreateDomainResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |