Class: Aws::Lightsail::Types::CreateInstancesFromSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateInstancesFromSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_ons ⇒ Array<Types::AddOnRequest>
An array of objects representing the add-ons to enable for the new instance.
-
#attached_disk_mapping ⇒ Hash<String,Array<Types::DiskMap>>
An object containing information about one or more disk mappings.
-
#availability_zone ⇒ String
The Availability Zone where you want to create your instances.
-
#bundle_id ⇒ String
The bundle of specification information for your virtual private server (or instance), including the pricing plan (
micro_x_x). -
#instance_names ⇒ Array<String>
The names for your new instances.
-
#instance_snapshot_name ⇒ String
The name of the instance snapshot on which you are basing your new instances.
-
#ip_address_type ⇒ String
The IP address type for the instance.
-
#key_pair_name ⇒ String
The name for your key pair.
-
#restore_date ⇒ String
The date of the automatic snapshot to use for the new instance.
-
#source_instance_name ⇒ String
The name of the source instance from which the source automatic snapshot was created.
-
#tags ⇒ Array<Types::Tag>
The tag keys and optional values to add to the resource during create.
-
#use_latest_restorable_auto_snapshot ⇒ Boolean
A Boolean value to indicate whether to use the latest available automatic snapshot.
-
#user_data ⇒ String
You can create a launch script that configures a server with additional user data.
Instance Attribute Details
#add_ons ⇒ Array<Types::AddOnRequest>
An array of objects representing the add-ons to enable for the new instance.
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#attached_disk_mapping ⇒ Hash<String,Array<Types::DiskMap>>
An object containing information about one or more disk mappings.
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone where you want to create your instances. Use the following formatting: us-east-2a (case sensitive). You can get a list of Availability Zones by using the [get regions][1] operation. Be sure to add the ‘include Availability Zones` parameter to your request.
[1]: docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRegions.html
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#bundle_id ⇒ String
The bundle of specification information for your virtual private server (or instance), including the pricing plan (micro_x_x).
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#instance_names ⇒ Array<String>
The names for your new instances.
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#instance_snapshot_name ⇒ String
The name of the instance snapshot on which you are basing your new instances. Use the get instance snapshots operation to return information about your existing snapshots.
Constraint:
-
This parameter cannot be defined together with the ‘source instance name` parameter. The `instance snapshot name` and `source instance name` parameters are mutually exclusive.
^
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type for the instance.
The possible values are ipv4 for IPv4 only, ipv6 for IPv6 only, and dualstack for IPv4 and IPv6.
The default value is dualstack.
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#key_pair_name ⇒ String
The name for your key pair.
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#restore_date ⇒ String
The date of the automatic snapshot to use for the new instance. Use the ‘get auto snapshots` operation to identify the dates of the available automatic snapshots.
Constraints:
-
Must be specified in
YYYY-MM-DDformat. -
This parameter cannot be defined together with the ‘use latest restorable auto snapshot` parameter. The `restore date` and `use latest restorable auto snapshot` parameters are mutually exclusive.
-
Define this parameter only when creating a new instance from an automatic snapshot. For more information, see the [Amazon Lightsail Developer Guide][1].
[1]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-configuring-automatic-snapshots
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#source_instance_name ⇒ String
The name of the source instance from which the source automatic snapshot was created.
Constraints:
-
This parameter cannot be defined together with the ‘instance snapshot name` parameter. The `source instance name` and `instance snapshot name` parameters are mutually exclusive.
-
Define this parameter only when creating a new instance from an automatic snapshot. For more information, see the [Amazon Lightsail Developer Guide][1].
[1]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-configuring-automatic-snapshots
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tag keys and optional values to add to the resource during create.
Use the TagResource action to tag a resource after it’s created.
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#use_latest_restorable_auto_snapshot ⇒ Boolean
A Boolean value to indicate whether to use the latest available automatic snapshot.
Constraints:
-
This parameter cannot be defined together with the ‘restore date` parameter. The `use latest restorable auto snapshot` and `restore date` parameters are mutually exclusive.
-
Define this parameter only when creating a new instance from an automatic snapshot. For more information, see the [Amazon Lightsail Developer Guide][1].
[1]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-configuring-automatic-snapshots
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |
#user_data ⇒ String
You can create a launch script that configures a server with additional user data. For example, ‘apt-get -y update`.
<note markdown=“1”> Depending on the machine image you choose, the command to get software on your instance varies. Amazon Linux and CentOS use yum, Debian and Ubuntu use apt-get, and FreeBSD uses pkg. For a complete list, see the [Amazon Lightsail Developer Guide][1].
</note>
[1]: docs.aws.amazon.com/lightsail/latest/userguide/compare-options-choose-lightsail-instance-image
4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4085 class CreateInstancesFromSnapshotRequest < Struct.new( :instance_names, :attached_disk_mapping, :availability_zone, :instance_snapshot_name, :bundle_id, :user_data, :key_pair_name, :tags, :add_ons, :ip_address_type, :source_instance_name, :restore_date, :use_latest_restorable_auto_snapshot) SENSITIVE = [] include Aws::Structure end |