Class: Aws::Lightsail::Types::CreateLoadBalancerResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operationsArray<Types::Operation>

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.



4362
4363
4364
4365
4366
# File 'lib/aws-sdk-lightsail/types.rb', line 4362

class CreateLoadBalancerResult < Struct.new(
  :operations)
  SENSITIVE = []
  include Aws::Structure
end