Class: Aws::Lightsail::Types::CreateRelationalDatabaseFromSnapshotResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::CreateRelationalDatabaseFromSnapshotResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
4556 4557 4558 4559 4560 |
# File 'lib/aws-sdk-lightsail/types.rb', line 4556 class CreateRelationalDatabaseFromSnapshotResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |