Class: Aws::Lightsail::Types::DeleteBucketResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteBucketResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5045 5046 5047 5048 5049 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5045 class DeleteBucketResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |