Class: Aws::Lightsail::Types::DeleteDomainEntryResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::DeleteDomainEntryResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
5277 5278 5279 5280 5281 |
# File 'lib/aws-sdk-lightsail/types.rb', line 5277 class DeleteDomainEntryResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |