Class: Aws::Lightsail::Types::EnableAddOnResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::EnableAddOnResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
6303 6304 6305 6306 6307 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6303 class EnableAddOnResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |