Class: Aws::Lightsail::Types::ExportSnapshotResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::ExportSnapshotResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
6581 6582 6583 6584 6585 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6581 class ExportSnapshotResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |