Class: Aws::Lightsail::Types::GetActiveNamesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#active_namesArray<String>

The list of active names returned by the get active names request.

Returns:

  • (Array<String>)


6536
6537
6538
6539
6540
6541
# File 'lib/aws-sdk-lightsail/types.rb', line 6536

class GetActiveNamesResult < Struct.new(
  :active_names,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_page_tokenString

The token to advance to the next page of results from your request.

A next page token is not returned if there are no more results to display.

To get the next page of results, perform another GetActiveNames request and specify the next page token using the pageToken parameter.

Returns:

  • (String)


6536
6537
6538
6539
6540
6541
# File 'lib/aws-sdk-lightsail/types.rb', line 6536

class GetActiveNamesResult < Struct.new(
  :active_names,
  :next_page_token)
  SENSITIVE = []
  include Aws::Structure
end