Class: Aws::Lightsail::Types::GetBlueprintsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetBlueprintsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blueprints ⇒ Array<Types::Blueprint>
An array of key-value pairs that contains information about the available blueprints.
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#blueprints ⇒ Array<Types::Blueprint>
An array of key-value pairs that contains information about the available blueprints.
6769 6770 6771 6772 6773 6774 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6769 class GetBlueprintsResult < Struct.new( :blueprints, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetBlueprints
request and specify the next page token using the pageToken
parameter.
6769 6770 6771 6772 6773 6774 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6769 class GetBlueprintsResult < Struct.new( :blueprints, :next_page_token) SENSITIVE = [] include Aws::Structure end |