Class: Aws::Lightsail::Types::GetBucketsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetBucketsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The name of the bucket for which to return information.
-
#include_connected_resources ⇒ Boolean
A Boolean value that indicates whether to include Lightsail instances that were given access to the bucket using the [SetResourceAccessForBucket][1] action.
-
#include_cors ⇒ Boolean
A Boolean value that indicates whether to include Lightsail bucket CORS configuration in the response.
-
#page_token ⇒ String
The token to advance to the next page of results from your request.
Instance Attribute Details
#bucket_name ⇒ String
The name of the bucket for which to return information.
When omitted, the response includes all of your buckets in the Amazon Web Services Region where the request is made.
6904 6905 6906 6907 6908 6909 6910 6911 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6904 class GetBucketsRequest < Struct.new( :bucket_name, :page_token, :include_connected_resources, :include_cors) SENSITIVE = [] include Aws::Structure end |
#include_connected_resources ⇒ Boolean
A Boolean value that indicates whether to include Lightsail instances that were given access to the bucket using the
- SetResourceAccessForBucket][1
-
action.
[1]: docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_SetResourceAccessForBucket.html
6904 6905 6906 6907 6908 6909 6910 6911 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6904 class GetBucketsRequest < Struct.new( :bucket_name, :page_token, :include_connected_resources, :include_cors) SENSITIVE = [] include Aws::Structure end |
#include_cors ⇒ Boolean
A Boolean value that indicates whether to include Lightsail bucket CORS configuration in the response. For more information, see [Configuring cross-origin resource sharing (CORS)][1].
<note markdown=“1”> This parameter is only supported when getting a single bucket with bucketName specified. The default value for this parameter is False.
</note>
[1]: docs.aws.amazon.com/lightsail/latest/userguide/configure-cors.html
6904 6905 6906 6907 6908 6909 6910 6911 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6904 class GetBucketsRequest < Struct.new( :bucket_name, :page_token, :include_connected_resources, :include_cors) SENSITIVE = [] include Aws::Structure end |
#page_token ⇒ String
The token to advance to the next page of results from your request.
To get a page token, perform an initial GetBuckets request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request.
6904 6905 6906 6907 6908 6909 6910 6911 |
# File 'lib/aws-sdk-lightsail/types.rb', line 6904 class GetBucketsRequest < Struct.new( :bucket_name, :page_token, :include_connected_resources, :include_cors) SENSITIVE = [] include Aws::Structure end |