Class: Aws::Lightsail::Types::GetContainerServicesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetContainerServicesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_name ⇒ String
The name of the container service for which to return information.
Instance Attribute Details
#service_name ⇒ String
The name of the container service for which to return information.
When omitted, the response includes all of your container services in the Amazon Web Services Region where the request is made.
7463 7464 7465 7466 7467 |
# File 'lib/aws-sdk-lightsail/types.rb', line 7463 class GetContainerServicesRequest < Struct.new( :service_name) SENSITIVE = [] include Aws::Structure end |