Class: Aws::Lightsail::Types::GetOperationsForResourceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetOperationsForResourceResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_page_count ⇒ String
(Discontinued) Returns the number of pages of results that remain.
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#next_page_count ⇒ String
(Discontinued) Returns the number of pages of results that remain.
<note markdown=“1”> In releases prior to June 12, 2017, this parameter returned ‘null` by the API. It is now discontinued, and the API returns the `next page token` parameter instead.
</note>
8970 8971 8972 8973 8974 8975 8976 |
# File 'lib/aws-sdk-lightsail/types.rb', line 8970 class GetOperationsForResourceResult < Struct.new( :operations, :next_page_count, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another ‘GetOperationsForResource` request and specify the next page token using the `pageToken` parameter.
8970 8971 8972 8973 8974 8975 8976 |
# File 'lib/aws-sdk-lightsail/types.rb', line 8970 class GetOperationsForResourceResult < Struct.new( :operations, :next_page_count, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
8970 8971 8972 8973 8974 8975 8976 |
# File 'lib/aws-sdk-lightsail/types.rb', line 8970 class GetOperationsForResourceResult < Struct.new( :operations, :next_page_count, :next_page_token) SENSITIVE = [] include Aws::Structure end |