Class: Aws::Lightsail::Types::GetRelationalDatabaseMasterUserPasswordRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetRelationalDatabaseMasterUserPasswordRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#password_version ⇒ String
The password version to return.
-
#relational_database_name ⇒ String
The name of your database for which to get the master user password.
Instance Attribute Details
#password_version ⇒ String
The password version to return.
Specifying CURRENT or PREVIOUS returns the current or previous passwords respectively. Specifying PENDING returns the newest version of the password that will rotate to CURRENT. After the PENDING password rotates to CURRENT, the PENDING password is no longer available.
Default: CURRENT
9332 9333 9334 9335 9336 9337 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9332 class GetRelationalDatabaseMasterUserPasswordRequest < Struct.new( :relational_database_name, :password_version) SENSITIVE = [] include Aws::Structure end |
#relational_database_name ⇒ String
The name of your database for which to get the master user password.
9332 9333 9334 9335 9336 9337 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9332 class GetRelationalDatabaseMasterUserPasswordRequest < Struct.new( :relational_database_name, :password_version) SENSITIVE = [] include Aws::Structure end |