Class: Aws::Lightsail::Types::GetSetupHistoryResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::GetSetupHistoryResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
-
#setup_history ⇒ Array<Types::SetupHistory>
The historical information that's returned.
Instance Attribute Details
#next_page_token ⇒ String
The token to advance to the next page of results from your request.
A next page token is not returned if there are no more results to display.
To get the next page of results, perform another GetSetupHistory
request and specify the next page token using the pageToken
parameter.
9854 9855 9856 9857 9858 9859 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9854 class GetSetupHistoryResult < Struct.new( :setup_history, :next_page_token) SENSITIVE = [] include Aws::Structure end |
#setup_history ⇒ Array<Types::SetupHistory>
The historical information that's returned.
9854 9855 9856 9857 9858 9859 |
# File 'lib/aws-sdk-lightsail/types.rb', line 9854 class GetSetupHistoryResult < Struct.new( :setup_history, :next_page_token) SENSITIVE = [] include Aws::Structure end |