Class: Aws::Lightsail::Types::ImportKeyPairResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::ImportKeyPairResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
10064 10065 10066 10067 10068 |
# File 'lib/aws-sdk-lightsail/types.rb', line 10064 class ImportKeyPairResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |