Class: Aws::Lightsail::Types::KeyPair

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Describes an SSH key pair.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the key pair (‘arn:aws:lightsail:us-east-2:123456789101:KeyPair/05859e3d-331d-48ba-9034-12345EXAMPLE`).

Returns:

  • (String)


11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
# File 'lib/aws-sdk-lightsail/types.rb', line 11101

class KeyPair < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :fingerprint)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the key pair was created (‘1479816991.349`).

Returns:

  • (Time)


11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
# File 'lib/aws-sdk-lightsail/types.rb', line 11101

class KeyPair < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :fingerprint)
  SENSITIVE = []
  include Aws::Structure
end

#fingerprintString

The RSA fingerprint of the key pair.

Returns:

  • (String)


11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
# File 'lib/aws-sdk-lightsail/types.rb', line 11101

class KeyPair < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :fingerprint)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::ResourceLocation

The region name and Availability Zone where the key pair was created.



11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
# File 'lib/aws-sdk-lightsail/types.rb', line 11101

class KeyPair < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :fingerprint)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The friendly name of the SSH key pair.

Returns:

  • (String)


11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
# File 'lib/aws-sdk-lightsail/types.rb', line 11101

class KeyPair < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :fingerprint)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type (usually ‘KeyPair`).

Returns:

  • (String)


11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
# File 'lib/aws-sdk-lightsail/types.rb', line 11101

class KeyPair < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :fingerprint)
  SENSITIVE = []
  include Aws::Structure
end

#support_codeString

The support code. Include this code in your email to support when you have questions about an instance or another resource in Lightsail. This code enables our support team to look up your Lightsail information more easily.

Returns:

  • (String)


11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
# File 'lib/aws-sdk-lightsail/types.rb', line 11101

class KeyPair < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :fingerprint)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tag keys and optional values for the resource. For more information about tags in Lightsail, see the [Amazon Lightsail Developer Guide].

[1]: docs.aws.amazon.com/lightsail/latest/userguide/amazon-lightsail-tags

Returns:



11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
# File 'lib/aws-sdk-lightsail/types.rb', line 11101

class KeyPair < Struct.new(
  :name,
  :arn,
  :support_code,
  :created_at,
  :location,
  :resource_type,
  :tags,
  :fingerprint)
  SENSITIVE = []
  include Aws::Structure
end