Class: Aws::Lightsail::Types::NameServersUpdateState
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::NameServersUpdateState
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes the state of the name server records update made by Amazon Lightsail to an Amazon Route 53 registered domain.
For more information, see DNS in Amazon Lightsail in the Amazon Lightsail Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The status code for the name servers update.
-
#message ⇒ String
The message that describes the reason for the status code.
Instance Attribute Details
#code ⇒ String
The status code for the name servers update.
Following are the possible values:
-
SUCCEEDED- The name server records were successfully updated. -
PENDING- The name server record update is in progress. -
FAILED- The name server record update failed. -
STARTED- The automatic name server record update started.
12127 12128 12129 12130 12131 12132 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12127 class NameServersUpdateState < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The message that describes the reason for the status code.
12127 12128 12129 12130 12131 12132 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12127 class NameServersUpdateState < Struct.new( :code, :message) SENSITIVE = [] include Aws::Structure end |