Class: Aws::Lightsail::Types::OpenInstancePublicPortsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::OpenInstancePublicPortsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
12184 12185 12186 12187 12188 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12184 class OpenInstancePublicPortsResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |