Class: Aws::Lightsail::Types::Origin

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Describes the origin resource of an Amazon Lightsail content delivery network (CDN) distribution.

An origin can be a Lightsail instance, bucket, or load balancer. A distribution pulls content from an origin, caches it, and serves it to viewers via a worldwide network of edge servers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ip_address_typeString

The IP address type that the distribution uses when connecting to the origin.

The possible values are ‘ipv4` for IPv4 only, `ipv6` for IPv6 only, and `dualstack` for IPv4 and IPv6.

Returns:

  • (String)


12202
12203
12204
12205
12206
12207
12208
12209
12210
12211
# File 'lib/aws-sdk-lightsail/types.rb', line 12202

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the origin resource.

Returns:

  • (String)


12202
12203
12204
12205
12206
12207
12208
12209
12210
12211
# File 'lib/aws-sdk-lightsail/types.rb', line 12202

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#protocol_policyString

The protocol that your Amazon Lightsail distribution uses when establishing a connection with your origin to pull content.

Returns:

  • (String)


12202
12203
12204
12205
12206
12207
12208
12209
12210
12211
# File 'lib/aws-sdk-lightsail/types.rb', line 12202

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#region_nameString

The AWS Region name of the origin resource.

Returns:

  • (String)


12202
12203
12204
12205
12206
12207
12208
12209
12210
12211
# File 'lib/aws-sdk-lightsail/types.rb', line 12202

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type of the origin resource (Instance).

Returns:

  • (String)


12202
12203
12204
12205
12206
12207
12208
12209
12210
12211
# File 'lib/aws-sdk-lightsail/types.rb', line 12202

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#response_timeoutInteger

The amount of time, in seconds, that the distribution waits for a response after forwarding a request to the origin. The minimum timeout is 1 second, the maximum is 60 seconds, and the default (if you don’t specify otherwise) is 30 seconds.

Returns:

  • (Integer)


12202
12203
12204
12205
12206
12207
12208
12209
12210
12211
# File 'lib/aws-sdk-lightsail/types.rb', line 12202

class Origin < Struct.new(
  :name,
  :resource_type,
  :region_name,
  :protocol_policy,
  :response_timeout,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end