Class: Aws::Lightsail::Types::PartnerInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::PartnerInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
An object that contains information about the Lightsail partner program membership of an Amazon Lightsail account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enrolled_at ⇒ Time
The timestamp when the account was enrolled in the Lightsail partner program.
-
#status ⇒ String
The status of the partner membership.
-
#tier_name ⇒ String
The tier of the partner membership.
Instance Attribute Details
#enrolled_at ⇒ Time
The timestamp when the account was enrolled in the Lightsail partner program.
12374 12375 12376 12377 12378 12379 12380 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12374 class PartnerInfo < Struct.new( :enrolled_at, :tier_name, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the partner membership.
The following statuses are possible:
-
Active– The membership is active, and the benefits of the current tier are available to the account. -
Suspended– The membership is suspended, and the benefits of the tier are not available to the account.
12374 12375 12376 12377 12378 12379 12380 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12374 class PartnerInfo < Struct.new( :enrolled_at, :tier_name, :status) SENSITIVE = [] include Aws::Structure end |
#tier_name ⇒ String
The tier of the partner membership.
12374 12375 12376 12377 12378 12379 12380 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12374 class PartnerInfo < Struct.new( :enrolled_at, :tier_name, :status) SENSITIVE = [] include Aws::Structure end |