Class: Aws::Lightsail::Types::PeerVpcResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::PeerVpcResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
12269 12270 12271 12272 12273 |
# File 'lib/aws-sdk-lightsail/types.rb', line 12269 class PeerVpcResult < Struct.new( :operation) SENSITIVE = [] include Aws::Structure end |