Class: Aws::Lightsail::Types::ResetDistributionCacheResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::ResetDistributionCacheResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_time ⇒ Time
The timestamp of the reset cache request (
1479734909.17) in Unix time format. -
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
-
#status ⇒ String
The status of the reset cache request.
Instance Attribute Details
#create_time ⇒ Time
The timestamp of the reset cache request (1479734909.17) in Unix time format.
13628 13629 13630 13631 13632 13633 13634 |
# File 'lib/aws-sdk-lightsail/types.rb', line 13628 class ResetDistributionCacheResult < Struct.new( :status, :create_time, :operation) SENSITIVE = [] include Aws::Structure end |
#operation ⇒ Types::Operation
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
13628 13629 13630 13631 13632 13633 13634 |
# File 'lib/aws-sdk-lightsail/types.rb', line 13628 class ResetDistributionCacheResult < Struct.new( :status, :create_time, :operation) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the reset cache request.
13628 13629 13630 13631 13632 13633 13634 |
# File 'lib/aws-sdk-lightsail/types.rb', line 13628 class ResetDistributionCacheResult < Struct.new( :status, :create_time, :operation) SENSITIVE = [] include Aws::Structure end |