Class: Aws::Lightsail::Types::SetResourceAccessForBucketResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::SetResourceAccessForBucketResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
13954 13955 13956 13957 13958 |
# File 'lib/aws-sdk-lightsail/types.rb', line 13954 class SetResourceAccessForBucketResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |