Class: Aws::Lightsail::Types::SetResourceAccessForBucketResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::SetResourceAccessForBucketResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14123 14124 14125 14126 14127 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14123 class SetResourceAccessForBucketResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |