Class: Aws::Lightsail::Types::StartRelationalDatabaseResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::StartRelationalDatabaseResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14211 14212 14213 14214 14215 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14211 class StartRelationalDatabaseResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |