Class: Aws::Lightsail::Types::StaticIp
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::StaticIp
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Describes a static IP.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the static IP (‘arn:aws:lightsail:us-east-2:123456789101:StaticIp/9cbb4a9e-f8e3-4dfe-b57e-12345EXAMPLE`).
-
#attached_to ⇒ String
The instance where the static IP is attached (‘Amazon_Linux-1GB-Ohio-1`).
-
#created_at ⇒ Time
The timestamp when the static IP was created (‘1479735304.222`).
-
#ip_address ⇒ String
The static IP address.
-
#is_attached ⇒ Boolean
A Boolean value indicating whether the static IP is attached.
-
#location ⇒ Types::ResourceLocation
The region and Availability Zone where the static IP was created.
-
#name ⇒ String
The name of the static IP (‘StaticIP-Ohio-EXAMPLE`).
-
#resource_type ⇒ String
The resource type (usually ‘StaticIp`).
-
#support_code ⇒ String
The support code.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the static IP (‘arn:aws:lightsail:us-east-2:123456789101:StaticIp/9cbb4a9e-f8e3-4dfe-b57e-12345EXAMPLE`).
14262 14263 14264 14265 14266 14267 14268 14269 14270 14271 14272 14273 14274 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14262 class StaticIp < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :ip_address, :attached_to, :is_attached) SENSITIVE = [] include Aws::Structure end |
#attached_to ⇒ String
The instance where the static IP is attached (‘Amazon_Linux-1GB-Ohio-1`).
14262 14263 14264 14265 14266 14267 14268 14269 14270 14271 14272 14273 14274 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14262 class StaticIp < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :ip_address, :attached_to, :is_attached) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the static IP was created (‘1479735304.222`).
14262 14263 14264 14265 14266 14267 14268 14269 14270 14271 14272 14273 14274 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14262 class StaticIp < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :ip_address, :attached_to, :is_attached) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
The static IP address.
14262 14263 14264 14265 14266 14267 14268 14269 14270 14271 14272 14273 14274 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14262 class StaticIp < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :ip_address, :attached_to, :is_attached) SENSITIVE = [] include Aws::Structure end |
#is_attached ⇒ Boolean
A Boolean value indicating whether the static IP is attached.
14262 14263 14264 14265 14266 14267 14268 14269 14270 14271 14272 14273 14274 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14262 class StaticIp < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :ip_address, :attached_to, :is_attached) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::ResourceLocation
The region and Availability Zone where the static IP was created.
14262 14263 14264 14265 14266 14267 14268 14269 14270 14271 14272 14273 14274 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14262 class StaticIp < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :ip_address, :attached_to, :is_attached) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the static IP (‘StaticIP-Ohio-EXAMPLE`).
14262 14263 14264 14265 14266 14267 14268 14269 14270 14271 14272 14273 14274 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14262 class StaticIp < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :ip_address, :attached_to, :is_attached) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type (usually ‘StaticIp`).
14262 14263 14264 14265 14266 14267 14268 14269 14270 14271 14272 14273 14274 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14262 class StaticIp < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :ip_address, :attached_to, :is_attached) SENSITIVE = [] include Aws::Structure end |
#support_code ⇒ String
The support code. Include this code in your email to support when you have questions about an instance or another resource in Lightsail. This code enables our support team to look up your Lightsail information more easily.
14262 14263 14264 14265 14266 14267 14268 14269 14270 14271 14272 14273 14274 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14262 class StaticIp < Struct.new( :name, :arn, :support_code, :created_at, :location, :resource_type, :ip_address, :attached_to, :is_attached) SENSITIVE = [] include Aws::Structure end |