Class: Aws::Lightsail::Types::UpdateBucketBundleResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateBucketBundleResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
Instance Attribute Details
#operations ⇒ Array<Types::Operation>
An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.
14646 14647 14648 14649 14650 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14646 class UpdateBucketBundleResult < Struct.new( :operations) SENSITIVE = [] include Aws::Structure end |