Class: Aws::Lightsail::Types::UpdateBucketResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketTypes::Bucket

An object that describes the bucket that is updated.

Returns:



14692
14693
14694
14695
14696
14697
# File 'lib/aws-sdk-lightsail/types.rb', line 14692

class UpdateBucketResult < Struct.new(
  :bucket,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end

#operationsArray<Types::Operation>

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.

Returns:



14692
14693
14694
14695
14696
14697
# File 'lib/aws-sdk-lightsail/types.rb', line 14692

class UpdateBucketResult < Struct.new(
  :bucket,
  :operations)
  SENSITIVE = []
  include Aws::Structure
end