Class: Aws::Lightsail::Types::UpdateDistributionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateDistributionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_behavior_settings ⇒ Types::CacheSettings
An object that describes the cache behavior settings for the distribution.
-
#cache_behaviors ⇒ Array<Types::CacheBehaviorPerPath>
An array of objects that describe the per-path cache behavior for the distribution.
-
#certificate_name ⇒ String
The name of the SSL/TLS certificate that you want to attach to the distribution.
-
#default_cache_behavior ⇒ Types::CacheBehavior
An object that describes the default cache behavior for the distribution.
-
#distribution_name ⇒ String
The name of the distribution to update.
-
#is_enabled ⇒ Boolean
Indicates whether to enable the distribution.
-
#origin ⇒ Types::InputOrigin
An object that describes the origin resource for the distribution, such as a Lightsail instance, bucket, or load balancer.
-
#use_default_certificate ⇒ Boolean
Indicates whether the default SSL/TLS certificate is attached to the distribution.
-
#viewer_minimum_tls_protocol_version ⇒ String
Use this parameter to update the minimum TLS protocol version for the SSL/TLS certificate that’s attached to the distribution.
Instance Attribute Details
#cache_behavior_settings ⇒ Types::CacheSettings
An object that describes the cache behavior settings for the distribution.
<note markdown=“1”> The cacheBehaviorSettings specified in your UpdateDistributionRequest will replace your distribution’s existing settings.
</note>
14900 14901 14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14900 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate) SENSITIVE = [] include Aws::Structure end |
#cache_behaviors ⇒ Array<Types::CacheBehaviorPerPath>
An array of objects that describe the per-path cache behavior for the distribution.
14900 14901 14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14900 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate) SENSITIVE = [] include Aws::Structure end |
#certificate_name ⇒ String
The name of the SSL/TLS certificate that you want to attach to the distribution.
Only certificates with a status of ISSUED can be attached to a distribution.
Use the [GetCertificates][1] action to get a list of certificate names that you can specify.
[1]: docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetCertificates.html
14900 14901 14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14900 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate) SENSITIVE = [] include Aws::Structure end |
#default_cache_behavior ⇒ Types::CacheBehavior
An object that describes the default cache behavior for the distribution.
14900 14901 14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14900 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate) SENSITIVE = [] include Aws::Structure end |
#distribution_name ⇒ String
The name of the distribution to update.
Use the GetDistributions action to get a list of distribution names that you can specify.
14900 14901 14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14900 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate) SENSITIVE = [] include Aws::Structure end |
#is_enabled ⇒ Boolean
Indicates whether to enable the distribution.
14900 14901 14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14900 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ Types::InputOrigin
An object that describes the origin resource for the distribution, such as a Lightsail instance, bucket, or load balancer.
The distribution pulls, caches, and serves content from the origin.
14900 14901 14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14900 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate) SENSITIVE = [] include Aws::Structure end |
#use_default_certificate ⇒ Boolean
Indicates whether the default SSL/TLS certificate is attached to the distribution. The default value is true. When true, the distribution uses the default domain name such as d111111abcdef8.cloudfront.net.
Set this value to false to attach a new certificate to the distribution.
14900 14901 14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14900 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate) SENSITIVE = [] include Aws::Structure end |
#viewer_minimum_tls_protocol_version ⇒ String
Use this parameter to update the minimum TLS protocol version for the SSL/TLS certificate that’s attached to the distribution.
14900 14901 14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/aws-sdk-lightsail/types.rb', line 14900 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate) SENSITIVE = [] include Aws::Structure end |