Class: Aws::Lightsail::Types::UpdateDistributionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lightsail::Types::UpdateDistributionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lightsail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_behavior_settings ⇒ Types::CacheSettings
An object that describes the cache behavior settings for the distribution.
-
#cache_behaviors ⇒ Array<Types::CacheBehaviorPerPath>
An array of objects that describe the per-path cache behavior for the distribution.
-
#certificate_name ⇒ String
The name of the SSL/TLS certificate that you want to attach to the distribution.
-
#custom_error_responses ⇒ Array<Types::DistributionCustomErrorResponse>
An array of objects that describe the custom error responses for the distribution.
-
#default_cache_behavior ⇒ Types::CacheBehavior
An object that describes the default cache behavior for the distribution.
-
#default_root_object ⇒ String
The object (for example,
index.html) that the distribution returns when a viewer requests the root URL of the distribution (/) instead of a specific object. -
#distribution_name ⇒ String
The name of the distribution to update.
-
#enable_private_origin_access ⇒ Boolean
Specifies whether to enable private origin access for the distribution.
-
#is_enabled ⇒ Boolean
Indicates whether to enable the distribution.
-
#origin ⇒ Types::InputOrigin
An object that describes the origin resource for the distribution, such as a Lightsail instance, bucket, or load balancer.
-
#use_default_certificate ⇒ Boolean
Indicates whether the default SSL/TLS certificate is attached to the distribution.
-
#viewer_minimum_tls_protocol_version ⇒ String
Use this parameter to update the minimum TLS protocol version for the SSL/TLS certificate that's attached to the distribution.
Instance Attribute Details
#cache_behavior_settings ⇒ Types::CacheSettings
An object that describes the cache behavior settings for the distribution.
cacheBehaviorSettings specified in your
UpdateDistributionRequest will replace your distribution's
existing settings.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#cache_behaviors ⇒ Array<Types::CacheBehaviorPerPath>
An array of objects that describe the per-path cache behavior for the distribution.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#certificate_name ⇒ String
The name of the SSL/TLS certificate that you want to attach to the distribution.
Only certificates with a status of ISSUED can be attached to a
distribution.
Use the GetCertificates action to get a list of certificate names that you can specify.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#custom_error_responses ⇒ Array<Types::DistributionCustomErrorResponse>
An array of objects that describe the custom error responses for the distribution. With a custom error response, you can specify the page to return when the origin responds with a given HTTP error code. You can also specify the HTTP status code to send to the viewer.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#default_cache_behavior ⇒ Types::CacheBehavior
An object that describes the default cache behavior for the distribution.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#default_root_object ⇒ String
The object (for example, index.html) that the distribution returns
when a viewer requests the root URL of the distribution (/)
instead of a specific object. The object that you specify must be
available from the origin.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#distribution_name ⇒ String
The name of the distribution to update.
Use the GetDistributions action to get a list of distribution
names that you can specify.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#enable_private_origin_access ⇒ Boolean
Specifies whether to enable private origin access for the distribution. With private origin access, the distribution can serve objects that aren't publicly accessible from a Lightsail bucket.
Lightsail grants the distribution permission to read the bucket's objects. Enabling private origin access doesn't change the bucket's access settings, and you can still retrieve publicly accessible objects directly from the bucket's endpoint.
origin
parameter with the resource name, even if the origin is not
changing.
You can enable private origin access only when the distribution's origin is a Lightsail bucket. If the origin is another resource type, the request fails.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#is_enabled ⇒ Boolean
Indicates whether to enable the distribution.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ Types::InputOrigin
An object that describes the origin resource for the distribution, such as a Lightsail instance, bucket, or load balancer.
The distribution pulls, caches, and serves content from the origin.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#use_default_certificate ⇒ Boolean
Indicates whether the default SSL/TLS certificate is attached to the
distribution. The default value is true. When true, the
distribution uses the default domain name such as
d111111abcdef8.cloudfront.net.
Set this value to false to attach a new certificate to the
distribution.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |
#viewer_minimum_tls_protocol_version ⇒ String
Use this parameter to update the minimum TLS protocol version for the SSL/TLS certificate that's attached to the distribution.
15140 15141 15142 15143 15144 15145 15146 15147 15148 15149 15150 15151 15152 15153 15154 15155 |
# File 'lib/aws-sdk-lightsail/types.rb', line 15140 class UpdateDistributionRequest < Struct.new( :distribution_name, :origin, :default_cache_behavior, :cache_behavior_settings, :cache_behaviors, :is_enabled, :viewer_minimum_tls_protocol_version, :certificate_name, :use_default_certificate, :enable_private_origin_access, :default_root_object, :custom_error_responses) SENSITIVE = [] include Aws::Structure end |