Class: Aws::Lightsail::Types::UpdateDomainEntryResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lightsail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operationsArray<Types::Operation>

An array of objects that describe the result of the action, such as the status of the request, the timestamp of the request, and the resources affected by the request.



14954
14955
14956
14957
14958
# File 'lib/aws-sdk-lightsail/types.rb', line 14954

class UpdateDomainEntryResult < Struct.new(
  :operations)
  SENSITIVE = []
  include Aws::Structure
end